@@ -15,6 +15,10 @@
 #' @examples
 #' iscambinomnorm(k = 10, n = 20, prob = 0.5, direction = "two.sided")
 iscambinomnorm <- function(k, n, prob, direction, verbose = TRUE) {
+  if (.iscam_maybe_help(k, "iscambinomnorm")) {
+    return(invisible())
+  }
+
   old <- par(mar = c(5, 3, 1, 1))
   on.exit(par(old), add = TRUE)
   thisx <- 0:n
@@ -22,19 +26,14 @@ iscambinomnorm <- function(k, n, prob, direction, verbose = TRUE) {
   minx <- max(0, n * prob - 4 * sqrt(prob * (1 - prob) * n))
   maxx <- max(k + 1, min(n, n * prob + 4 * sqrt(prob * (1 - prob) * n)))
   myy <- max(dbinom(floor(n * prob), n, prob))
-  plot(
-    thisx,
-    dbinom(thisx, size = n, prob),
-    xlab = "",
-    ylab = " ",
-    type = "h",
+  .iscam_plot_discrete_distribution(
+    x = thisx,
+    prob_y = dbinom(thisx, size = n, prob),
     xlim = c(minx, maxx),
-    panel.first = grid(),
-    lwd = 2
+    x_label = "Number of Successes (Proportion)",
+    y_label = "Probability (Density)",
+    x_line = 3
   )
-  abline(h = 0, col = "gray")
-  mtext(side = 1, line = 3, "Number of Successes (Proportion)")
-  mtext(side = 2, line = 2, "Probability (Density)")
 
   axis(
     side = 1,
@@ -46,74 +45,88 @@ iscambinomnorm <- function(k, n, prob, direction, verbose = TRUE) {
   )
   normmean <- n * prob
   normsd <- sqrt(n * prob * (1 - prob))
-  normseq <- seq(0, n, .001)
+  normseq <- seq(0, n, by = max(0.001, abs(n - 0) / 2000))
   lines(normseq, dnorm(normseq, normmean, normsd), col = "grey")
-  if (direction == "below") {
-    probseq <- seq(0, k, .001)
-    phatseq <- probseq / n
-    withcorrect <- seq(0, k + .5, .001)
-    this.prob <- pbinom(k, n, prob)
-    normprob <- pnorm(k, normmean, normsd)
-    normprob2 <- pnorm(k + .5, normmean, normsd)
-    showprob <- format(this.prob, digits = 4)
-    showprob2 <- format(normprob, digits = 4)
-    showprob3 <- format(normprob2, digits = 4)
-    polygon(
-      c(withcorrect, k + .5, 0),
-      c(dnorm(withcorrect, normmean, normsd), 0, 0),
-      col = 6,
-      border = 6
+  if (direction %in% c("below", "above")) {
+    lower_tail <- direction == "below"
+    tail_out <- .iscam_discrete_tail_probability(
+      k = k,
+      lower.tail = lower_tail,
+      cdf_lower = function(x) pbinom(x, n, prob),
+      cdf_upper = function(x) 1 - pbinom(x - 1, n, prob),
+      digits = 4
     )
-    polygon(
-      c(probseq, k, 0),
-      c(dnorm(probseq, normmean, normsd), 0, 0),
-      col = "light blue",
-      border = "blue"
+    tail_regions <- .iscam_discrete_tail_regions(
+      k = k,
+      lower_bound = 0,
+      upper_bound = n,
+      lower.tail = lower_tail
     )
-    lines(0:k, dbinom(0:k, size = n, prob), col = "red", type = "h", lwd = 2)
-    # lines(phatseq, dnorm(probseq,normmean,normsd))
-    text(
-      minx,
-      myy * .9,
-      labels = bquote(atop(P(X <= .(k)), "=" ~ .(showprob))),
+    norm_out <- .iscam_normal_tail_probs_with_cc(
+      k = k,
+      mean = normmean,
+      sd = normsd,
+      lower.tail = lower_tail,
+      digits = 4
+    )
+    this.prob <- tail_out$prob
+    showprob <- tail_out$showprob
+    showprob2 <- norm_out$showprob
+    showprob3 <- norm_out$showprob_corrected
+
+    if (lower_tail) {
+      polygon(
+        c(tail_regions$corrected_seq, tail_regions$corrected_cutoff, 0),
+        c(dnorm(tail_regions$corrected_seq, normmean, normsd), 0, 0),
+        col = 6,
+        border = 6
+      )
+      polygon(
+        c(tail_regions$tail_seq, k, 0),
+        c(dnorm(tail_regions$tail_seq, normmean, normsd), 0, 0),
+        col = "light blue",
+        border = "blue"
+      )
+    } else {
+      polygon(
+        c(tail_regions$corrected_cutoff, tail_regions$corrected_seq, n),
+        c(0, dnorm(tail_regions$corrected_seq, normmean, normsd), 0),
+        col = 6,
+        border = 6
+      )
+      polygon(
+        c(k, tail_regions$tail_seq, n),
+        c(0, dnorm(tail_regions$tail_seq, normmean, normsd), 0),
+        col = "light blue",
+        border = "blue"
+      )
+    }
+
+    .iscam_draw_discrete_tail_spikes(
+      k = k,
+      upper = n,
+      lower.tail = lower_tail,
+      pmf_fn = function(x) dbinom(x, size = n, prob),
       col = "red",
-      pos = 4
+      lwd = 2
     )
-  } else if (direction == "above") {
-    this.prob <- 1 - pbinom(k - 1, n, prob)
-    probseq <- seq(k, n, .001)
-    withcorrect <- seq(k - .5, n, .001)
-    normprob <- pnorm(k, normmean, normsd, lower.tail = FALSE)
-    normprob2 <- pnorm(k - .5, normmean, normsd, lower.tail = FALSE)
-    showprob <- format(this.prob, digits = 4)
-    showprob2 <- format(normprob, digits = 4)
-    showprob3 <- format(normprob2, digits = 4)
-    polygon(
-      c(k - .5, withcorrect, n),
-      c(0, dnorm(withcorrect, normmean, normsd), 0),
-      col = 6,
-      border = 6
-    )
-    polygon(
-      c(k, probseq, n),
-      c(0, dnorm(probseq, normmean, normsd), 0),
-      col = "light blue",
-      border = "blue"
-    )
-    lines(k:n, dbinom(k:n, size = n, prob), col = "red", type = "h", lwd = 2)
     text(
-      maxx,
-      myy * .9,
-      labels = bquote(atop(P(X >= .(k)), "=" ~ .(showprob))),
+      .iscam_tail_choice(lower_tail, minx, maxx),
+      myy * 0.9,
+      labels = .iscam_discrete_tail_label(
+        k = k,
+        showprob = showprob,
+        lower.tail = lower_tail
+      ),
       col = "red",
-      pos = 2
+      pos = .iscam_tail_choice(lower_tail, 4, 2)
     )
   } else if (direction == "two.sided") {
     if (k < normmean) {
       k1 <- k
       k2 <- floor(min(normmean - k + normmean, n))
       newvalue <- dbinom(k2, size = n, prob)
-      if (newvalue <= dbinom(k1, size = n, prob) + .00001) {
+      if (newvalue <= dbinom(k1, size = n, prob) + 0.00001) {
         k2 <- k2
       } else {
         k2 <- k2 + 1
@@ -122,7 +135,7 @@ iscambinomnorm <- function(k, n, prob, direction, verbose = TRUE) {
       k1 <- floor(min(normmean - (k - normmean), n))
       k2 <- k
       newvalue <- dbinom(k1, size = n, prob)
-      if (newvalue <= dbinom(k, size = n, prob) + .00001) {
+      if (newvalue <= dbinom(k, size = n, prob) + 0.00001) {
         k1 <- k1
       } else {
         k1 <- k1 - 1
@@ -132,17 +145,21 @@ iscambinomnorm <- function(k, n, prob, direction, verbose = TRUE) {
       pbinom(k2 - 1, n, prob, lower.tail = FALSE)
     normprob <- pnorm(k1, normmean, normsd) +
       pnorm(k2, normmean, normsd, lower.tail = FALSE)
-    normprob2 <- pnorm(k1 + .5, normmean, normsd) +
-      pnorm(k2 - .5, normmean, normsd, lower.tail = FALSE)
+    normprob2 <- pnorm(k1 + 0.5, normmean, normsd) +
+      pnorm(k2 - 0.5, normmean, normsd, lower.tail = FALSE)
     showprob <- format(this.prob, digits = 4)
     showprob2 <- format(normprob, digits = 4)
     showprob3 <- format(normprob2, digits = 4)
-    probseq1 <- seq(0, k1, .001)
-    probseq2 <- seq(k2, n, .001)
-    withcorrect <- seq(0, k1 + .5, .001)
-    withcorrect2 <- seq(k2 - .5, n, .001)
+    probseq1 <- seq(0, k1, by = max(0.001, abs(k1 - 0) / 2000))
+    probseq2 <- seq(k2, n, by = max(0.001, abs(n - k2) / 2000))
+    withcorrect <- seq(0, k1 + 0.5, by = max(0.001, abs(k1 + 0.5 - 0) / 2000))
+    withcorrect2 <- seq(
+      k2 - 0.5,
+      n,
+      by = max(0.001, abs(n - (k2 - 0.5)) / 2000)
+    )
     polygon(
-      c(withcorrect, k1 + .5, 0),
+      c(withcorrect, k1 + 0.5, 0),
       c(dnorm(withcorrect, normmean, normsd), 0, 0),
       col = 6,
       border = 6
@@ -154,7 +171,7 @@ iscambinomnorm <- function(k, n, prob, direction, verbose = TRUE) {
       border = "blue"
     )
     polygon(
-      c(k2 - .5, withcorrect2, n),
+      c(k2 - 0.5, withcorrect2, n),
       c(0, dnorm(withcorrect2, normmean, normsd), 0),
       col = 6,
       border = 6
@@ -169,7 +186,7 @@ iscambinomnorm <- function(k, n, prob, direction, verbose = TRUE) {
     lines(k2:n, dbinom(k2:n, size = n, prob), col = "red", type = "h")
     text(
       minx,
-      myy * .85,
+      myy * 0.85,
       labels = bquote(
         atop(
           P(X <= .(k1)) + P(X >= .(k2)),
@@ -238,6 +255,10 @@ iscambinompower <- function(
   prob2 = NULL,
   verbose = TRUE
 ) {
+  if (.iscam_maybe_help(LOS, "iscambinompower")) {
+    return(invisible())
+  }
+
   thisx <- 0:n
   minx <- max(
     0,
@@ -449,6 +470,10 @@ iscambinompower <- function(
 #' iscambinomprob(k = 15, n = 30, prob = 0.3, lower.tail = FALSE)
 #' iscambinomprob(k = 22, n = 25, prob = 0.9, lower.tail = TRUE)
 iscambinomprob <- function(k, n, prob, lower.tail, verbose = TRUE) {
+  if (.iscam_maybe_help(k, "iscambinomprob")) {
+    return(invisible())
+  }
+
   if (prob < 0 || prob > 1) {
     stop("Error: `prob` (probability) must be a numeric value between 0 and 1.")
   }
@@ -459,7 +484,6 @@ iscambinomprob <- function(k, n, prob, lower.tail, verbose = TRUE) {
   minx <- max(0, n * prob - 4 * sqrt(prob * (1 - prob) * n))
   maxx <- min(n, n * prob + 4 * sqrt(prob * (1 - prob) * n))
   maxx <- max(k + 1, maxx)
-  #   myy=dbinom(floor(n*prob), n, prob)/2
   myy <- dbinom(floor(n * prob), n, prob)
   plot(
     thisx,
@@ -487,8 +511,7 @@ iscambinomprob <- function(k, n, prob, lower.tail, verbose = TRUE) {
     if (verbose) {
       cat("Probability", k, "and below =", this.prob, "\n")
     }
-  }
-  if (!lower.tail) {
+  } else {
     this.prob <- 1 - pbinom(k - 1, n, prob)
     showprob <- format(this.prob, digits = 4)
     lines(k:n, dbinom(k:n, size = n, prob), col = "red", type = "h", lwd = 2)
@@ -511,7 +534,7 @@ iscambinomprob <- function(k, n, prob, lower.tail, verbose = TRUE) {
   mtext(side = 1, line = 2, "Number of Successes")
   mtext(side = 2, line = 2, "Probability")
 
-  return(this.prob)
+  invisible(this.prob)
 }
 
 #' Exact Binomial Test
@@ -565,12 +588,14 @@ iscambinomtest <- function(
   conf.level = NULL,
   verbose = TRUE
 ) {
+  if (.iscam_maybe_help(observed, "iscambinomtest")) {
+    return(invisible())
+  }
+
   old <- par(mar = c(4, 3, 2, 2))
   on.exit(par(old), add = TRUE)
 
-  if (observed < 1) {
-    observed <- round(n * observed)
-  }
+  observed <- .iscam_as_count(observed, n)
   pvalue <- NULL
   if (!is.null(hypothesized)) {
     minx <- max(
@@ -582,7 +607,7 @@ iscambinomtest <- function(
       n * hypothesized + 4 * sqrt(hypothesized * (1 - hypothesized) * n)
     )
     maxx <- max(observed + 1, maxx)
-    myy <- max(dbinom(floor(n * hypothesized), n, hypothesized)) * .9
+    myy <- max(dbinom(floor(n * hypothesized), n, hypothesized)) * 0.9
     x <- 0:n
     plot(
       x,
@@ -594,11 +619,7 @@ iscambinomtest <- function(
       panel.first = grid(),
       lwd = 2
     )
-    newtitle <- substitute(
-      paste("Binomial (", n == x1, ", ", pi == x2, ")", ),
-      list(x1 = n, x2 = hypothesized)
-    )
-    title(newtitle)
+    title(.iscam_binom_title(n, hypothesized))
     mtext(side = 1, line = 2, "Number of Successes")
     mtext(side = 2, line = 2, "Probability")
 
@@ -619,8 +640,7 @@ iscambinomtest <- function(
         col = "red"
       )
     } else if (alternative == "greater") {
-      value <- observed - 1
-      pvalue <- pbinom(value, size = n, prob = hypothesized, FALSE)
+      pvalue <- pbinom(observed - 1, size = n, prob = hypothesized, FALSE)
       lines(
         observed:n,
         dbinom(observed:n, size = n, prob = hypothesized),
@@ -636,15 +656,12 @@ iscambinomtest <- function(
         col = "red"
       )
     } else {
-      pvalue <- 0
-      firstvalue <- dbinom(observed, size = n, prob = hypothesized)
-      for (y in 0:n) {
-        newvalue <- dbinom(y, size = n, prob = hypothesized)
-        if (newvalue <= firstvalue + .00001) {
-          pvalue <- pvalue + newvalue
-          lines(y, newvalue, col = "red", type = "h", lwd = 2)
-        }
-      }
+      xvals <- 0:n
+      probabilities <- dbinom(xvals, size = n, prob = hypothesized)
+      cutoff <- dbinom(observed, size = n, prob = hypothesized) + 1e-05
+      keep <- probabilities <= cutoff
+      pvalue <- sum(probabilities[keep])
+      lines(xvals[keep], probabilities[keep], col = "red", type = "h", lwd = 2)
       text(
         minx,
         myy,
@@ -687,65 +704,50 @@ iscambinomtest <- function(
       cat(paste("p-value:", pvalue, sep = " "), "\n")
     }
   }
-  p.L <- function(x, alpha) {
-    if (x == 0) {
-      0
-    } else {
-      qbeta(alpha, x, n - x + 1)
-    }
-  }
-  p.U <- function(x, alpha) {
-    if (x == n) {
-      1
-    } else {
-      qbeta(1 - alpha, x + 1, n - x)
-    }
-  }
-  CINT <- 0
-  multconflevel <- 0
   lower1 <- NULL
   upper1 <- NULL
   if (!is.null(conf.level)) {
-    for (k in 1:length(conf.level)) {
-      if (conf.level[k] > 1) {
-        conf.level[k] <- conf.level[k] / 100
-      }
+    conf.level <- .iscam_normalize_conf_levels(conf.level)
+    for (k in seq_along(conf.level)) {
       alpha <- (1 - conf.level[k]) / 2
-      CINT <- c(
-        signif(p.L(observed, alpha), 5),
-        ",",
-        signif(p.U(observed, alpha), 5)
-      )
-      multconflevel <- 100 * conf.level[k]
+      lower1[k] <- if (observed == 0) {
+        0
+      } else {
+        qbeta(alpha, observed, n - observed + 1)
+      }
+      upper1[k] <- if (observed == n) {
+        1
+      } else {
+        qbeta(1 - alpha, observed + 1, n - observed)
+      }
       if (verbose) {
-        cat(multconflevel, "% Confidence interval for pi: (", CINT, ") \n")
+        CINT <- c(signif(lower1[k], 5), ",", signif(upper1[k], 5))
+        cat(
+          100 * conf.level[k],
+          "% Confidence interval for pi: (",
+          CINT,
+          ") \n"
+        )
       }
-      lower1[k] <- as.numeric(CINT[1])
-      upper1[k] <- as.numeric(CINT[3])
     }
   }
-  old <- par(mar = c(4, 2, 1.5, .5), mfrow = c(3, 1))
+  old <- par(mar = c(4, 2, 1.5, 0.5), mfrow = c(3, 1))
   on.exit(par(old), add = TRUE)
   if (length(conf.level) > 1) {
-    old <- par(mar = c(4, 2, 1.5, .4), mfrow = c(length(conf.level), 1))
+    old <- par(mar = c(4, 2, 1.5, 0.4), mfrow = c(length(conf.level), 1))
     on.exit(par(old), add = TRUE)
   }
 
   if (is.null(hypothesized)) {
     statistic <- observed / n
-    # lower=lower1[1]; upper=upper1[1]
     SDphat <- sqrt(statistic * (1 - statistic) / n)
     min <- statistic - 4 * SDphat
     max <- statistic + 4 * SDphat
-    CIseq <- seq(min, max, .01)
     minx <- as.integer(max(0, min * n))
     maxx <- as.integer(min(n, max * n))
 
     if (length(conf.level) == 1) {
-      myxlab <- substitute(
-        paste("Binomial (", n == x1, ", ", pi == x2, ")", ),
-        list(x1 = n, x2 = signif(lower1[1], 4))
-      )
+      myxlab <- .iscam_binom_title(n, signif(lower1[1], 4))
       plot(
         seq(minx, maxx),
         dbinom(seq(minx, maxx), size = n, prob = lower1[1]),
@@ -754,7 +756,7 @@ iscambinomtest <- function(
         type = "h",
         xlim = c(minx, maxx)
       )
-      mtext("Number of successes", side = 1, line = 1.75, adj = .5, cex = .75)
+      mtext("Number of successes", side = 1, line = 1.75, adj = 0.5, cex = 0.75)
       title(myxlab)
       lines(
         observed:n,
@@ -763,10 +765,7 @@ iscambinomtest <- function(
         type = "h"
       )
 
-      myxlab <- substitute(
-        paste("Binomial (", n == x1, ", ", pi == x2, ")", ),
-        list(x1 = n, x2 = signif(upper1[1], 4))
-      )
+      myxlab <- .iscam_binom_title(n, signif(upper1[1], 4))
       plot(
         seq(minx, maxx),
         dbinom(seq(minx, maxx), size = n, prob = upper1[1]),
@@ -782,28 +781,22 @@ iscambinomtest <- function(
         type = "h"
       )
 
-      mtext("Number of successes", side = 1, line = 1.75, adj = .5, cex = .75)
+      mtext("Number of successes", side = 1, line = 1.75, adj = 0.5, cex = 0.75)
       title(myxlab)
-    } # end only one interval
+    }
 
-    for (k in 1:length(conf.level)) {
-      plot(
-        c(min, statistic, max),
-        c(1, 1, 1),
-        pch = c(".", "^", "."),
-        ylab = " ",
-        xlab = "process probability",
-        ylim = c(1, 1)
+    for (k in seq_along(conf.level)) {
+      .iscam_plot_ci_strip(
+        min_x = min,
+        statistic = statistic,
+        max_x = max,
+        lower = lower1[k],
+        upper = upper1[k],
+        x_label = "process probability",
+        ci_label = paste(conf.level[k] * 100, "% CI:")
       )
-      abline(v = statistic, col = "gray")
-      text(min, 1, labels = paste(conf.level[k] * 100, "% CI:"))
-      text(statistic, .9, labels = signif(statistic, 4))
-      text(lower1[k], 1, labels = signif(lower1[k], 4), pos = 3)
-      text(upper1[k], 1, labels = signif(upper1[k], 4), pos = 3)
-      points(c(lower1[k], upper1[k]), c(1, 1), pch = c("[", "]"))
-      lines(c(lower1[k], upper1[k]), c(1, 1))
-    } # end intervals loop
-  } # end no hypothesized
+    }
+  }
 
   old <- par(mfrow = c(1, 1))
   on.exit(par(old), add = TRUE)
@@ -828,6 +821,10 @@ iscambinomtest <- function(
 #'
 #' iscaminvbinom(alpha = 0.01, n = 60, prob = 0.10, lower.tail = FALSE)
 iscaminvbinom <- function(alpha, n, prob, lower.tail, verbose = TRUE) {
+  if (.iscam_maybe_help(alpha, "iscaminvbinom")) {
+    return(invisible())
+  }
+
   old <- par(mar = c(4, 3, 2, 2))
   on.exit(par(old), add = TRUE)
 
@@ -845,6 +842,7 @@ iscaminvbinom <- function(alpha, n, prob, lower.tail, verbose = TRUE) {
     panel.first = grid(),
     lwd = 2
   )
+  abline(h = 0, col = "gray")
   newtitle <- substitute(
     paste("Binomial (", n == x1, ", ", pi == x2, ")", ),
     list(x1 = n, x2 = prob)
@@ -852,8 +850,6 @@ iscaminvbinom <- function(alpha, n, prob, lower.tail, verbose = TRUE) {
   title(newtitle)
   mtext(side = 1, line = 2, "X = Number of Successes")
   mtext(side = 2, line = 2, "Probability")
-
-  abline(h = 0, col = "gray")
   if (lower.tail) {
     answer <- qbinom(alpha, n, prob, lower.tail) - 1
     actualprob <- format(pbinom(answer, n, prob, lower.tail), digits = 4)
@@ -897,8 +893,7 @@ iscaminvbinom <- function(alpha, n, prob, lower.tail, verbose = TRUE) {
         "\n"
       )
     }
-  }
-  if (!lower.tail) {
+  } else {
     answer <- qbinom(alpha, n, prob, lower.tail) + 1
     actualprob <- format(pbinom(answer - 1, n, prob, lower.tail), digits = 4)
     lines(
@@ -942,5 +937,126 @@ iscaminvbinom <- function(alpha, n, prob, lower.tail, verbose = TRUE) {
       )
     }
   }
-  answer
+  invisible(answer)
+}
+
+#' Plot a binomial mass function with shared ISCAM styling
+#'
+#' Internal plotting utility for binomial-family functions.
+#'
+#' @param n Number of trials.
+#' @param prob Success probability.
+#' @param xlim X-axis limits.
+#' @param x_axis_label X-axis label.
+#' @param y_axis_label Y-axis label.
+#' @param add_title Logical; if `TRUE`, draw the standard binomial title.
+#'
+#' @keywords internal
+#' @noRd
+.iscam_plot_binom_distribution <- function(
+  n,
+  prob,
+  xlim,
+  x_axis_label = "Number of Successes",
+  y_axis_label = "Probability",
+  add_title = TRUE
+) {
+  thisx <- 0:n
+  .iscam_plot_discrete_distribution(
+    x = thisx,
+    prob_y = dbinom(thisx, size = n, prob),
+    xlim = xlim,
+    x_label = x_axis_label,
+    y_label = y_axis_label,
+    lwd = 2
+  )
+  if (add_title) {
+    title(.iscam_binom_title(n, prob))
+  }
+}
+
+#' Draw the highlighted region for an exact binomial test
+#'
+#' Computes and draws the one- or two-sided exact test region and returns the
+#' corresponding p-value.
+#'
+#' @param observed Observed successes.
+#' @param n Number of trials.
+#' @param hypothesized Null success probability.
+#' @param alternative Tail direction (`"less"`, `"greater"`, `"two.sided"`).
+#' @param minx Left x-position for annotation.
+#' @param maxx Right x-position for annotation.
+#' @param myy Y-position for annotation.
+#'
+#' @return Numeric p-value for the highlighted region.
+#'
+#' @keywords internal
+#' @noRd
+.iscam_plot_exact_binom_region <- function(
+  observed,
+  n,
+  hypothesized,
+  alternative,
+  minx,
+  maxx,
+  myy
+) {
+  if (alternative == "less") {
+    pvalue <- pbinom(observed, size = n, prob = hypothesized, TRUE)
+    lines(
+      0:observed,
+      dbinom(0:observed, size = n, prob = hypothesized),
+      col = "red",
+      type = "h",
+      lwd = 2
+    )
+    text(
+      minx,
+      myy,
+      labels = paste("p-value:", signif(pvalue, 4)),
+      pos = 4,
+      col = "red"
+    )
+    return(pvalue)
+  }
+
+  if (alternative == "greater") {
+    pvalue <- pbinom(observed - 1, size = n, prob = hypothesized, FALSE)
+    lines(
+      observed:n,
+      dbinom(observed:n, size = n, prob = hypothesized),
+      col = "red",
+      type = "h",
+      lwd = 2
+    )
+    text(
+      maxx,
+      myy,
+      labels = paste("p-value:", signif(pvalue, 4)),
+      pos = 2,
+      col = "red"
+    )
+    return(pvalue)
+  }
+
+  xvals <- 0:n
+  probabilities <- dbinom(xvals, size = n, prob = hypothesized)
+  cutoff <- dbinom(observed, size = n, prob = hypothesized) + 0.00001
+  keep <- probabilities <= cutoff
+  pvalue <- sum(probabilities[keep])
+  lines(
+    xvals[keep],
+    probabilities[keep],
+    col = "red",
+    type = "h",
+    lwd = 2
+  )
+  text(
+    minx,
+    myy,
+    labels = paste("two-sided p-value:\n", signif(pvalue, 4)),
+    pos = 4,
+    col = "red"
+  )
+  pvalue
 }
