@@ -35,95 +35,84 @@ iscamnormprob <- function(
   digits = 4,
   verbose = TRUE
 ) {
-  old <- par(mar = c(4, 3, 2, 1))
-  on.exit(par(old), add = TRUE)
+  if (.iscam_maybe_help(xval, "iscamnormprob")) {
+    return(invisible())
+  }
 
-  if (is.null(xval2)) {
-    xval2 <- abs(xval)
-  }
-  if (xval2 < xval) {
-    temp <- xval
-    xval <- xval2
-    xval2 <- temp
-  }
+  old_par <- par(mar = c(4, 3, 2, 1))
+  on.exit(par(old_par), add = TRUE)
+
+  ordered_vals <- .iscam_resolve_interval_bounds(
+    xval = xval,
+    xval2 = xval2,
+    direction = direction,
+    default_xval2 = abs
+  )
+  xval <- ordered_vals[1]
+  xval2 <- ordered_vals[2]
   xvallabel <- format(xval, digits = digits)
   xval2label <- format(xval2, digits = digits)
-  old <- options("scipen" = 100, "digits" = digits)
-  on.exit(options(old), add = TRUE)
+  old_opts <- options("scipen" = 100, "digits" = digits)
+  on.exit(options(old_opts), add = TRUE)
 
-  minx <- min(mean - 4 * sd, xval - .15 * abs(xval))
-  maxx <- max(mean + 4 * sd, xval2 + .15 * xval2)
+  minx <- min(mean - 4 * sd, xval - 0.15 * abs(xval))
+  maxx <- max(mean + 4 * sd, xval2 + 0.15 * xval2)
 
-  thisx <- seq(minx, maxx, .001)
+  thisx <- seq(minx, maxx, by = max(0.001, abs(maxx - minx) / 2000))
   xlabel <- "x-variable"
   if (!is.null(label)) {
     xlabel <- label
   }
 
-  plot(
-    thisx,
-    dnorm(thisx, mean, sd),
+  .iscam_plot_continuous_distribution(
+    x = thisx,
+    density_y = dnorm(thisx, mean, sd),
     xlim = c(minx, maxx),
-    type = "l",
-    xlab = "",
-    ylab = " ",
-    lwd = 1,
-    panel.first = grid()
+    x_label = xlabel,
+    y_label = "Density"
   )
-  abline(h = 0, col = "gray")
-  mtext(side = 1, line = 2, xlabel)
-  mtext(side = 2, line = 2, "Density")
 
   if (direction == "below") {
-    probseq <- seq(minx, max(minx, xval), .001)
     normprob <- pnorm(xval, mean, sd)
     showprob <- format(normprob, digits = digits)
-    polygon(
-      c(probseq, max(minx, xval), minx),
-      c(dnorm(probseq, mean, sd), 0, 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_left_tail(
+      min_x = minx,
+      x_end = max(minx, xval),
+      density_fn = function(v) dnorm(v, mean, sd)
     )
     text(
       minx,
-      max(dnorm(mean, mean, sd)) * .9,
+      max(dnorm(mean, mean, sd)) * 0.9,
       labels = bquote(atop(P(X <= .(xvallabel)), "=" ~ .(showprob))),
       col = "red",
       pos = 4
     )
   } else if (direction == "above") {
-    probseq <- seq(min(xval, maxx), maxx, .001)
     normprob <- pnorm(xval, mean, sd, lower.tail = FALSE)
     showprob <- format(normprob, digits = digits)
-    polygon(
-      c(min(maxx, xval), probseq, maxx),
-      c(0, dnorm(probseq, mean, sd), 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_right_tail(
+      x_start = min(maxx, xval),
+      max_x = maxx,
+      density_fn = function(v) dnorm(v, mean, sd)
     )
     text(
       maxx,
-      max(dnorm(mean, mean, sd)) * .9,
+      max(dnorm(mean, mean, sd)) * 0.9,
       labels = bquote(atop(P(X >= .(xvallabel)), "=" ~ .(showprob))),
       col = "red",
       pos = 2
     )
   } else if (direction == "between") {
-    if (is.null(xval2)) {
-      stop("You need to specify a second observation value.")
-    }
-    probseq <- seq(xval, xval2, .001)
     normprob <- pnorm(xval2, mean, sd) - pnorm(xval, mean, sd)
     showprob <- format(normprob, digits = digits)
-    polygon(
-      c(xval, probseq, xval2),
-      c(0, dnorm(probseq, mean, sd), 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_between(
+      x_start = xval,
+      x_end = xval2,
+      density_fn = function(v) dnorm(v, mean, sd)
     )
     text(
       minx,
-      max(dnorm(mean, mean, sd)) * .9,
+      max(dnorm(mean, mean, sd)) * 0.9,
       labels = bquote(
         atop(
           P(.(xvallabel) <= X ~ "," ~ X <= .(xval2label)),
@@ -134,28 +123,22 @@ iscamnormprob <- function(
       pos = 4
     )
   } else if (direction == "outside") {
-    if (is.null(xval2)) {
-      stop("You need to specify a second observation value.")
-    }
-    probseq1 <- seq(minx, xval, .001)
-    probseq2 <- seq(xval2, maxx, .001)
     normprob <- 1 - (pnorm(xval2, mean, sd) - pnorm(xval, mean, sd))
     showprob <- format(normprob, digits = digits)
-    polygon(
-      c(minx, probseq1, xval),
-      c(0, dnorm(probseq1, mean, sd), 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_left_tail(
+      min_x = minx,
+      x_end = xval,
+      density_fn = function(v) dnorm(v, mean, sd),
+      baseline_start = TRUE
     )
-    polygon(
-      c(xval2, probseq2, maxx),
-      c(0, dnorm(probseq2, mean, sd), 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_right_tail(
+      x_start = xval2,
+      max_x = maxx,
+      density_fn = function(v) dnorm(v, mean, sd)
     )
     text(
       minx,
-      max(dnorm(mean, mean, sd)) * .9,
+      max(dnorm(mean, mean, sd)) * 0.9,
       labels = bquote(atop(
         P(X <= .(xvallabel)) ~ "and" ~ P(X >= .(xval2label)),
         "=" ~ .(showprob)
@@ -164,20 +147,16 @@ iscamnormprob <- function(
       pos = 4
     )
   } else {
-    stop(
-      "Use \"above\", \"below\", \"between\", or \"outside\" as the direction."
-    )
+    .iscam_stop_invalid_direction()
   }
 
   title(substitute(
     paste("Normal(", mean == x3, ",  ", SD == x4, ")"),
     list(x3 = mean, x4 = signif(sd, 4))
   ))
-  if (verbose) {
-    cat(c("probability:", showprob), "\n")
-  }
+  .iscam_print_probability(verbose, showprob)
 
-  showprob
+  invisible(showprob)
 }
 
 #' Inverse Normal Calculation
@@ -208,6 +187,10 @@ iscaminvnorm <- function(
   direction,
   verbose = TRUE
 ) {
+  if (.iscam_maybe_help(prob1, "iscaminvnorm")) {
+    return(invisible())
+  }
+
   if ((!missing(sd) && !missing(Sd)) && Sd != sd) {
     stop("`Sd` is deprecated; use `sd`. Don't set `Sd` and `sd`.")
   }
@@ -218,28 +201,24 @@ iscaminvnorm <- function(
   on.exit(par(old), add = TRUE)
   min <- mean - 4 * sd
   max <- mean + 4 * sd
-  thisx <- seq(min, max, .001)
+  thisx <- seq(min, max, by = max(0.001, abs(max - min) / 2000))
   varx <- "X"
-  if (mean == 0 & sd == 1) {
+  if (mean == 0 && sd == 1) {
     varx <- "Z"
   }
-  plot(
-    thisx,
-    dnorm(thisx, mean, sd),
-    xlab = "",
-    ylab = "density",
-    type = "l",
-    panel.first = grid()
+  .iscam_plot_continuous_distribution(
+    x = thisx,
+    density_y = dnorm(thisx, mean, sd),
+    x_label = paste(varx, " = variable"),
+    y_label = "density",
+    baseline_col = "black"
   )
   newtitle <- paste("Normal (mean =", mean, ", SD = ", sd, ")")
   title(newtitle)
-  mtext(side = 1, line = 2, paste(varx, " = variable"))
-  mtext(side = 2, line = 2, "density")
   ymax <- max(dnorm(mean, mean, sd))
-  abline(h = 0, col = "black")
   if (direction == "below") {
     answer <- signif(qnorm(prob1, mean, sd, TRUE), 4)
-    thisrange <- seq(min, answer, .001)
+    thisrange <- seq(min, answer, by = max(0.001, abs(answer - min) / 2000))
     polygon(
       c(thisrange, answer, answer),
       c(0, dnorm(thisrange, mean, sd), 0),
@@ -253,7 +232,7 @@ iscaminvnorm <- function(
     )
     text(
       answer,
-      min(dnorm(answer, mean, sd), ymax * .85),
+      min(dnorm(answer, mean, sd), ymax * 0.85),
       labels = bquote(.(as.name(varx)) <= .(answer)),
       col = "red",
       pos = 3
@@ -263,7 +242,7 @@ iscaminvnorm <- function(
     }
   } else if (direction == "above") {
     answer <- signif(qnorm(prob1, mean, sd, FALSE), 4)
-    thisrange <- seq(answer, max, .001)
+    thisrange <- seq(answer, max, by = max(0.001, abs(max - answer) / 2000))
     polygon(
       c(answer, thisrange, max),
       c(0, dnorm(thisrange, mean, sd), 0),
@@ -277,7 +256,7 @@ iscaminvnorm <- function(
     )
     text(
       answer,
-      min(dnorm(answer, mean, sd), ymax * .85),
+      min(dnorm(answer, mean, sd), ymax * 0.85),
       labels = bquote(.(as.name(varx)) >= .(answer)),
       col = "red",
       pos = 3
@@ -287,8 +266,12 @@ iscaminvnorm <- function(
     }
   } else if (direction == "between") {
     answer1 <- signif(qnorm((1 - prob1) / 2, mean, sd, TRUE), 4)
-    answer2 <- mean + (mean - answer1)
-    thisrange <- seq(answer1, answer2, .001)
+    answer2 <- .iscam_reflect_about(mean, answer1)
+    thisrange <- seq(
+      answer1,
+      answer2,
+      by = max(0.001, abs(answer2 - answer1) / 2000)
+    )
     polygon(
       c(answer1, thisrange, answer2),
       c(0, dnorm(thisrange, mean, sd), 0),
@@ -297,14 +280,14 @@ iscaminvnorm <- function(
     text(mean, dnorm(mean, mean, sd) / 2, labels = prob1, col = "blue")
     text(
       answer1,
-      min(dnorm(answer1, mean, sd), ymax * .85),
+      min(dnorm(answer1, mean, sd), ymax * 0.85),
       labels = bquote(.(as.name(varx)) >= .(answer1)),
       col = "red",
       pos = 3
     )
     text(
       answer2,
-      min(dnorm(answer1, mean, sd), ymax * .85),
+      min(dnorm(answer1, mean, sd), ymax * 0.85),
       labels = bquote(.(as.name(varx)) <= .(answer2)),
       col = "red",
       pos = 3
@@ -322,9 +305,9 @@ iscaminvnorm <- function(
     }
   } else if (direction == "outside") {
     answer1 <- signif(qnorm(prob1 / 2, mean, sd, TRUE), 4)
-    answer2 <- mean + (mean - answer1)
-    thisrange1 <- seq(min, answer1, .001)
-    thisrange2 <- seq(answer2, max, .001)
+    answer2 <- .iscam_reflect_about(mean, answer1)
+    thisrange1 <- seq(min, answer1, by = max(0.001, abs(answer1 - min) / 2000))
+    thisrange2 <- seq(answer2, max, by = max(0.001, abs(max - answer2) / 2000))
     polygon(
       c(min, thisrange1, answer1),
       c(0, dnorm(thisrange1, mean, sd), 0),
@@ -351,14 +334,14 @@ iscaminvnorm <- function(
     )
     text(
       answer1,
-      min(dnorm(answer2, mean, sd), ymax * .85),
+      min(dnorm(answer2, mean, sd), ymax * 0.85),
       labels = bquote(.(as.name(varx)) <= .(answer1)),
       col = "red",
       pos = 3
     )
     text(
       answer2,
-      min(dnorm(answer2, mean, sd), ymax * .85),
+      min(dnorm(answer2, mean, sd), ymax * 0.85),
       labels = bquote(.(as.name(varx)) >= .(answer2)),
       col = "red",
       pos = 3
@@ -399,6 +382,10 @@ iscaminvnorm <- function(
 #' iscamnormpower(0.10, n = 50, prob1 = 0.25, alternative = "less", prob2 = 0.15)
 #' iscamnormpower(0.05, n = 200, prob1 = 0.8, alternative = "two.sided", prob2 = 0.7)
 iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
+  if (.iscam_maybe_help(LOS, "iscamnormpower")) {
+    return(invisible())
+  }
+
   old <- par(mar = c(5, 4, 1, 1), mfrow = c(2, 1))
   on.exit(par(old), add = TRUE)
   minx <- max(
@@ -418,7 +405,7 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
   mean <- prob1
   std <- sqrt(prob1 * (1 - prob1) / n)
   myy1 <- dnorm(mean, mean, std) / 2
-  drawseq <- seq(minx, maxx, .001)
+  drawseq <- seq(minx, maxx, 0.001)
   plot(
     drawseq,
     dnorm(drawseq, mean, std),
@@ -432,7 +419,7 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
     rr <- qnorm(LOS, mean, std)
     this.prob1 <- pnorm(rr, mean, std)
     showprob1 <- format(this.prob1, digits = 4)
-    drawseq <- seq(minx, rr, .001)
+    drawseq <- seq(minx, rr, 0.001)
     polygon(
       c(drawseq, rr, minx),
       c(dnorm(drawseq, mean, std), 0, 0),
@@ -454,7 +441,7 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
     this.prob1 <- 1 - pnorm(rr, mean, std)
 
     showprob1 <- format(this.prob1, digits = 4)
-    drawseq <- seq(rr, maxx, .001)
+    drawseq <- seq(rr, maxx, 0.001)
     polygon(
       c(drawseq, maxx, rr),
       c(dnorm(drawseq, mean, std), 0, 0),
@@ -479,13 +466,13 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
     showlowerprob1 <- format(lowerprob1, digits = 4)
     showupperprob1 <- format(upperprob1, digits = 4)
     showprob1 <- format(lowerprob1 + upperprob1, digits = 4)
-    drawseq <- seq(minx, lowerrr, .001)
+    drawseq <- seq(minx, lowerrr, 0.001)
     polygon(
       c(drawseq, lowerrr, minx),
       c(dnorm(drawseq, mean, std), 0, 0),
       col = "red"
     )
-    drawseq <- seq(upperrr, maxx, .001)
+    drawseq <- seq(upperrr, maxx, 0.001)
     polygon(
       c(drawseq, maxx, upperrr),
       c(dnorm(drawseq, mean, std), 0, 0),
@@ -522,7 +509,7 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
   if (!is.null(prob2)) {
     mean2 <- prob2
     std2 <- sqrt(prob2 * (1 - prob2) / n)
-    drawseq <- seq(minx, maxx, .001)
+    drawseq <- seq(minx, maxx, 0.001)
     plot(
       drawseq,
       dnorm(drawseq, mean2, std2),
@@ -536,7 +523,7 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
       rr <- qnorm(LOS, mean, std)
       this.prob2 <- pnorm(rr, mean2, std2)
       showprob2 <- format(this.prob2, digits = 4)
-      drawseq <- seq(minx, rr, .001)
+      drawseq <- seq(minx, rr, 0.001)
       polygon(
         c(drawseq, rr, minx),
         c(dnorm(drawseq, mean2, std2), 0, 0),
@@ -557,7 +544,7 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
       rr <- qnorm(LOS, mean, std, FALSE)
       this.prob2 <- 1 - pnorm(rr, mean2, std2)
       showprob2 <- format(this.prob2, digits = 4)
-      drawseq <- seq(rr, maxx, .001)
+      drawseq <- seq(rr, maxx, 0.001)
       polygon(
         c(drawseq, maxx, rr),
         c(dnorm(drawseq, mean2, std2), 0, 0),
@@ -582,13 +569,13 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
       showlowerprob2 <- format(lowerprob2, digits = 4)
       showupperprob2 <- format(upperprob2, digits = 4)
       showprob2 <- format(lowerprob2 + upperprob2, digits = 4)
-      drawseq <- seq(minx, lowerrr, .001)
+      drawseq <- seq(minx, lowerrr, 0.001)
       polygon(
         c(drawseq, lowerrr, minx),
         c(dnorm(drawseq, mean2, std2), 0, 0),
         col = "blue"
       )
-      drawseq <- seq(upperrr, maxx, .001)
+      drawseq <- seq(upperrr, maxx, 0.001)
       polygon(
         c(drawseq, maxx, upperrr),
         c(dnorm(drawseq, mean2, std2), 0, 0),
@@ -640,13 +627,12 @@ iscamnormpower <- function(LOS, n, prob1, alternative, prob2, verbose = TRUE) {
 #' @param observed The observed number of successes. If a value less than 1 is
 #' provided, it is assumed to be the sample proportion.
 #' @param n The sample size.
-#' @param hypothesized The hypothesized probability of success under the null
-#' hypothesis. This is an optional parameter.
-#' @param alternative A character string specifying the form of the alternative
-#' hypothesis. Must be one of "less", "greater", or "two.sided". This is
-#' an optional parameter.
-#' @param conf.level The confidence level(s) for a two-sided confidence
-#' interval. This is an optional parameter.
+#' @param hypothesized (optional) hypothesized probability of success under the null
+#' hypothesis.
+#' @param alternative (optional) character string specifying the form of the alternative
+#' hypothesis. Must be one of "less", "greater", or "two.sided".
+#' @param conf.level (optional) confidence level(s) for a two-sided confidence
+#' interval.
 #' @param verbose Logical, defaults to `TRUE`. Set to `FALSE` to suppress messages
 #'
 #' @return This function prints the results of the one-proportion z-test and/or
@@ -674,16 +660,19 @@ iscamonepropztest <- function(
   conf.level = NULL,
   verbose = TRUE
 ) {
+  if (.iscam_maybe_help(observed, "iscamonepropztest")) {
+    return(invisible())
+  }
+
   old <- par(mar = c(5, 3, 1, 1))
   on.exit(par(old), add = TRUE)
   if (observed < 1) {
-    observed = round(n * observed)
+    observed <- round(n * observed)
   }
-  myout = prop.test(observed, n, hypothesized, alternative, correct = FALSE)
   if (verbose) {
     cat("\nOne Proportion z test\n\n")
   }
-  statistic = signif(observed / n, 4)
+  statistic <- signif(observed / n, 4)
   if (verbose) {
     cat(paste(
       "Data: observed successes = ",
@@ -696,13 +685,13 @@ iscamonepropztest <- function(
       sep = ""
     ))
   }
-  zvalue = NULL
-  pvalue = NULL
+  zvalue <- NULL
+  pvalue <- NULL
   if (!is.null(hypothesized)) {
     if (verbose) {
       cat(paste("Null hypothesis       : pi =", hypothesized, sep = " "), "\n")
     }
-    altname = switch(
+    altname <- switch(
       alternative,
       less = "<",
       greater = ">",
@@ -715,19 +704,26 @@ iscamonepropztest <- function(
         "\n"
       )
     }
-    zvalue = (statistic - hypothesized) /
+    zvalue <- (statistic - hypothesized) /
       sqrt(hypothesized * (1 - hypothesized) / n)
     if (verbose) {
       cat("z-statistic:", signif(zvalue, 4), "\n")
     }
-    pvalue = signif(myout$p.value, 4)
+    pvalue <- switch(
+      alternative,
+      less = pnorm(zvalue),
+      greater = pnorm(zvalue, lower.tail = FALSE),
+      two.sided = 2 * pnorm(-abs(zvalue)),
+      not.equal = 2 * pnorm(-abs(zvalue))
+    )
+    pvalue <- signif(pvalue, 4)
     if (verbose) {
       cat("p-value:", pvalue, "\n")
     }
-    SD = sqrt(hypothesized * (1 - hypothesized) / n)
-    min = min(hypothesized - 4 * SD, hypothesized - abs(zvalue) * SD - .001)
-    max = max(hypothesized + 4 * SD, hypothesized + abs(zvalue) * SD + .001)
-    x = seq(min, max, .001)
+    SD <- sqrt(hypothesized * (1 - hypothesized) / n)
+    min <- min(hypothesized - 4 * SD, hypothesized - abs(zvalue) * SD - 0.001)
+    max <- max(hypothesized + 4 * SD, hypothesized + abs(zvalue) * SD + 0.001)
+    x <- seq(min, max, 0.001)
     plot(
       x,
       dnorm(x, hypothesized, SD),
@@ -738,7 +734,7 @@ iscamonepropztest <- function(
       panel.first = grid()
     )
 
-    zseq = c(
+    zseq <- c(
       hypothesized - 3 * SD,
       hypothesized - 2 * SD,
       hypothesized - SD,
@@ -759,7 +755,7 @@ iscamonepropztest <- function(
     mtext(side = 1, line = 3, bquote("<-" ~ "Sample Proportions" ~ "->"))
     mtext(side = 2, line = 2, "Density")
     if (alternative == "less") {
-      drawseq = seq(min, statistic, .001)
+      drawseq <- seq(min, statistic, 0.001)
       polygon(
         c(drawseq, statistic, min),
         c(dnorm(drawseq, hypothesized, SD), 0, 0),
@@ -767,20 +763,20 @@ iscamonepropztest <- function(
       )
       text(
         min,
-        max(dnorm(hypothesized, hypothesized, SD)) * .9,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.9,
         labels = paste("z-statistic:", signif(zvalue, 4)),
         pos = 4,
         col = "blue"
       )
       text(
         min,
-        max(dnorm(hypothesized, hypothesized, SD)) * .8,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.8,
         labels = paste("p-value:", pvalue),
         pos = 4,
         col = "red"
       )
     } else if (alternative == "greater") {
-      drawseq = seq(statistic, max, .001)
+      drawseq <- seq(statistic, max, 0.001)
       polygon(
         c(statistic, drawseq, max),
         c(0, dnorm(drawseq, hypothesized, SD), 0),
@@ -788,25 +784,25 @@ iscamonepropztest <- function(
       )
       text(
         max,
-        max(dnorm(hypothesized, hypothesized, SD)) * .9,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.9,
         labels = paste("z-statistic:", signif(zvalue, 4)),
         pos = 2,
         col = "blue"
       )
       text(
         max,
-        max(dnorm(hypothesized, hypothesized, SD)) * .8,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.8,
         labels = paste("p-value:", pvalue),
         pos = 2,
         col = "red"
       )
     } else if (alternative == "two.sided" || alternative == "not.equal") {
       if (statistic < hypothesized) {
-        drawseq1 = seq(min, statistic, .001)
-        drawseq2 = seq(hypothesized + (hypothesized - statistic), max, .001)
+        drawseq1 <- seq(min, statistic, 0.001)
+        drawseq2 <- seq(hypothesized + (hypothesized - statistic), max, 0.001)
       } else {
-        drawseq1 = seq(min, hypothesized - (statistic - hypothesized), .001)
-        drawseq2 = seq(statistic, max, .001)
+        drawseq1 <- seq(min, hypothesized - (statistic - hypothesized), 0.001)
+        drawseq2 <- seq(statistic, max, 0.001)
       }
       polygon(
         c(min, drawseq1, drawseq1[length(drawseq1)]),
@@ -820,14 +816,14 @@ iscamonepropztest <- function(
       )
       text(
         min,
-        max(dnorm(hypothesized, hypothesized, SD)) * .9,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.9,
         labels = paste("z-statistic:", signif(zvalue, 4)),
         pos = 4,
         col = "blue"
       )
       text(
         min,
-        max(dnorm(hypothesized, hypothesized, SD)) * .8,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.8,
         labels = paste("two-sided p-value:", pvalue),
         pos = 4,
         col = "red"
@@ -840,27 +836,17 @@ iscamonepropztest <- function(
     old <- par(mar = c(4, 2, 1.5, 4), mfrow = c(length(conf.level), 1))
     on.exit(par(old), add = TRUE)
   }
-  lower = 0
-  upper = 0
+  lower <- 0
+  upper <- 0
   if (!is.null(conf.level)) {
-    for (k in 1:length(conf.level)) {
-      if (conf.level[k] > 1) {
-        conf.level[k] = conf.level[k] / 100
-      }
-      myout = prop.test(
-        observed,
-        n,
-        p = statistic,
-        alternative = "two.sided",
-        conf.level[k],
-        correct = FALSE
-      )
-      criticalvalue = qnorm((1 - conf.level[k]) / 2)
-      lower[k] = statistic +
+    conf.level <- .iscam_normalize_conf_levels(conf.level)
+    for (k in seq_along(conf.level)) {
+      criticalvalue <- qnorm((1 - conf.level[k]) / 2)
+      lower[k] <- statistic +
         criticalvalue * sqrt(statistic * (1 - statistic) / n)
-      upper[k] = statistic -
+      upper[k] <- statistic -
         criticalvalue * sqrt(statistic * (1 - statistic) / n)
-      multconflevel = 100 * conf.level[k]
+      multconflevel <- 100 * conf.level[k]
       if (verbose) {
         cat(
           multconflevel,
@@ -873,37 +859,50 @@ iscamonepropztest <- function(
       }
     }
     if (is.null(hypothesized)) {
-      SDphat = sqrt(statistic * (1 - statistic) / n)
-      min = statistic - 4 * SDphat
-      max = statistic + 4 * SDphat
-      CIseq = seq(min, max, .001)
+      SDphat <- sqrt(statistic * (1 - statistic) / n)
+      min <- statistic - 4 * SDphat
+      max <- statistic + 4 * SDphat
+      CIseq <- seq(min, max, 0.001)
 
       if (length(conf.level) == 1) {
-        myxlab = substitute(
+        myxlab <- substitute(
           paste("Normal (", mean == x1, ", ", SD == x2, ")", ),
           list(x1 = signif(lower[1], 4), x2 = signif(SDphat, 4))
         )
         plot(CIseq, dnorm(CIseq, lower[1], SDphat), type = "l", xlab = " ")
-        mtext("sample proportions", side = 1, line = 1.75, adj = .5, cex = .75)
-        topseq = seq(statistic, max, .001)
+        mtext(
+          "sample proportions",
+          side = 1,
+          line = 1.75,
+          adj = 0.5,
+          cex = 0.75
+        )
+        topseq <- seq(statistic, max, 0.001)
         polygon(
           c(statistic, topseq, max),
           c(0, dnorm(topseq, lower[1], SDphat), 0),
           col = "red"
         )
         title(myxlab)
-        myxlab = substitute(
+        myxlab <- substitute(
           paste("Normal (", mean == x1, ", ", SD == x2, ")", ),
           list(x1 = signif(upper[1], 4), x2 = signif(SDphat, 4))
         )
+        upper_curve <- seq(min, max, 0.001)
         plot(
-          seq(min, max, .001),
-          dnorm(seq(min, max, .001), upper[1], SDphat),
+          upper_curve,
+          dnorm(upper_curve, upper[1], SDphat),
           type = "l",
           xlab = " "
         )
-        mtext("sample proportions", side = 1, line = 1.75, adj = .5, cex = .75)
-        bottomseq = seq(min, statistic, .001)
+        mtext(
+          "sample proportions",
+          side = 1,
+          line = 1.75,
+          adj = 0.5,
+          cex = 0.75
+        )
+        bottomseq <- seq(min, statistic, 0.001)
         polygon(
           c(min, bottomseq, statistic, statistic),
           c(
@@ -914,28 +913,23 @@ iscamonepropztest <- function(
           ),
           col = "red"
         )
-        newtitle = substitute(
+        newtitle <- substitute(
           paste("Normal (", mean == x1, ", ", SD == x2, ")", ),
           list(x1 = signif(upper[1], 4), x2 = signif(SDphat, 4))
         )
         title(newtitle)
       }
-      for (k in 1:length(conf.level)) {
-        plot(
-          c(min, statistic, max),
-          c(1, 1, 1),
-          pch = c(".", "^", "."),
-          ylab = " ",
-          xlab = "process probability",
-          ylim = c(1, 1)
+      for (k in seq_along(conf.level)) {
+        .iscam_plot_ci_strip(
+          min_x = min,
+          statistic = statistic,
+          max_x = max,
+          lower = lower[k],
+          upper = upper[k],
+          x_label = "process probability",
+          ci_label = paste(conf.level[k] * 100, "% CI:"),
+          ci_label_x = min * 1.1
         )
-        abline(v = statistic, col = "gray")
-        text(min * 1.1, 1, labels = paste(conf.level[k] * 100, "% CI:"))
-        text(statistic, .9, labels = signif(statistic, 4))
-        text(lower[k], 1, labels = signif(lower[k], 4), pos = 3)
-        text(upper[k], 1, labels = signif(upper[k], 4), pos = 3)
-        points(c(lower[k], upper[k]), c(1, 1), pch = c("[", "]"))
-        lines(c(lower[k], upper[k]), c(1, 1))
       }
     }
   }
@@ -960,15 +954,14 @@ iscamonepropztest <- function(
 #' @param observed2 The observed number of successes in group 2. If a value less than 1 is
 #' provided, it is assumed to be the sample proportion.
 #' @param n2 The sample size for group 2.
-#' @param hypothesized The hypothesized difference in probability of success under the null
-#' hypothesis. This is an optional parameter.
-#' @param alternative A character string specifying the form of the alternative
-#' hypothesis. Must be one of "less", "greater", or "two.sided". This is
-#' an optional parameter.
-#' @param conf.level The confidence level(s) for a two-sided confidence
-#' interval. This is an optional parameter.
-#' @param datatable A two-way table of counts as an alternative input method.
-#' This is an optional parameter.
+#' @param hypothesized (optional) hypothesized difference in probability of success
+#' under the null hypothesis.
+#' @param alternative (optional) character string specifying the form of the alternative
+#' hypothesis. Must be one of "less", "greater", or "two.sided".
+#' @param conf.level (optional) confidence level(s) for a two-sided confidence
+#' interval.
+#' @param datatable (optional) two-way table of counts as an alternative input
+#' method.
 #' @param verbose Logical, defaults to `TRUE`. Set to `FALSE` to suppress messages
 #'
 #' @return This function prints the results of the two-proportion z-test and/or
@@ -1001,30 +994,36 @@ iscamtwopropztest <- function(
   datatable = NULL,
   verbose = TRUE
 ) {
+  if (
+    !missing(observed1) && .iscam_maybe_help(observed1, "iscamtwopropztest")
+  ) {
+    return(invisible())
+  }
+
   old <- par(mar = c(5, 3, 1, 1))
   on.exit(par(old), add = TRUE)
 
   if (!is.null(datatable)) {
-    observed1 = datatable[1]
-    n1 = datatable[1] + datatable[2]
-    observed2 = datatable[3]
-    n2 = datatable[3] + datatable[4]
+    observed1 <- datatable[1]
+    n1 <- datatable[1] + datatable[2]
+    observed2 <- datatable[3]
+    n2 <- datatable[3] + datatable[4]
   }
 
-  pvalue = NULL
-  zvalue = NULL
+  pvalue <- NULL
+  zvalue <- NULL
   if (observed1 < 1) {
-    observed1 = round(n1 * observed1)
+    observed1 <- round(n1 * observed1)
   }
   if (observed2 < 1) {
-    observed2 = round(n2 * observed2)
+    observed2 <- round(n2 * observed2)
   }
   if (verbose) {
     cat("\nTwo Proportion z test\n\n")
   }
-  statistic1 = observed1 / n1
-  statistic2 = observed2 / n2
-  statistic = statistic1 - statistic2
+  statistic1 <- observed1 / n1
+  statistic2 <- observed2 / n2
+  statistic <- statistic1 - statistic2
   if (verbose) {
     cat(paste(
       "Group1: observed successes = ",
@@ -1054,7 +1053,7 @@ iscamtwopropztest <- function(
         "\n"
       )
     }
-    altname = switch(
+    altname <- switch(
       alternative,
       less = "<",
       greater = ">",
@@ -1072,17 +1071,17 @@ iscamtwopropztest <- function(
         "\n"
       )
     }
-    pooledphat = (observed1 + observed2) / (n1 + n2)
-    zvalue = (statistic1 - statistic2 - hypothesized) /
+    pooledphat <- (observed1 + observed2) / (n1 + n2)
+    zvalue <- (statistic1 - statistic2 - hypothesized) /
       sqrt(pooledphat * (1 - pooledphat) * (1 / n1 + 1 / n2))
     if (verbose) {
       cat("z-statistic:", signif(zvalue, 4), "\n")
     }
-    pvalue = 2
-    SD = sqrt(pooledphat * (1 - pooledphat) * (1 / n1 + 1 / n2))
-    min = min(hypothesized - 4 * SD, hypothesized - abs(zvalue) * SD - .001)
-    max = max(hypothesized + 4 * SD, hypothesized + abs(zvalue) * SD + .001)
-    x = seq(min, max, .001)
+    pvalue <- 2
+    SD <- sqrt(pooledphat * (1 - pooledphat) * (1 / n1 + 1 / n2))
+    min <- min(hypothesized - 4 * SD, hypothesized - abs(zvalue) * SD - 0.001)
+    max <- max(hypothesized + 4 * SD, hypothesized + abs(zvalue) * SD + 0.001)
+    x <- seq(min, max, 0.001)
     plot(
       x,
       dnorm(x, hypothesized, SD),
@@ -1091,7 +1090,7 @@ iscamtwopropztest <- function(
       ylim = c(0, dnorm(hypothesized, hypothesized, SD)),
       panel.first = grid()
     )
-    zseq = c(
+    zseq <- c(
       hypothesized - 3 * SD,
       hypothesized - 2 * SD,
       hypothesized - SD,
@@ -1109,7 +1108,7 @@ iscamtwopropztest <- function(
       col.axis = "blue"
     )
     abline(h = 0, col = "black")
-    newtitle = paste(
+    newtitle <- paste(
       "Normal (mean=",
       hypothesized,
       ", SD=",
@@ -1120,8 +1119,8 @@ iscamtwopropztest <- function(
     mtext(side = 2, line = 2, "density")
 
     if (alternative == "less") {
-      pvalue = signif(pnorm(zvalue), 4)
-      drawseq = seq(min, statistic, .001)
+      pvalue <- signif(pnorm(zvalue), 4)
+      drawseq <- seq(min, statistic, 0.001)
       polygon(
         c(drawseq, statistic, min),
         c(dnorm(drawseq, hypothesized, SD), 0, 0),
@@ -1129,21 +1128,21 @@ iscamtwopropztest <- function(
       )
       text(
         min,
-        max(dnorm(hypothesized, hypothesized, SD)) * .9,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.9,
         labels = paste("z-statistic:", signif(zvalue, 4)),
         pos = 4,
         col = "blue"
       )
       text(
         min,
-        max(dnorm(hypothesized, hypothesized, SD)) * .8,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.8,
         labels = paste("p-value:", pvalue),
         pos = 4,
         col = "red"
       )
     } else if (alternative == "greater") {
-      pvalue = signif(1 - pnorm(zvalue), 4)
-      drawseq = seq(statistic, max, .001)
+      pvalue <- signif(1 - pnorm(zvalue), 4)
+      drawseq <- seq(statistic, max, 0.001)
       polygon(
         c(statistic, drawseq, max),
         c(0, dnorm(drawseq, hypothesized, SD), 0),
@@ -1151,26 +1150,26 @@ iscamtwopropztest <- function(
       )
       text(
         max,
-        max(dnorm(hypothesized, hypothesized, SD)) * .9,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.9,
         labels = paste("z-statistic:", signif(zvalue, 4)),
         pos = 2,
         col = "blue"
       )
       text(
         max,
-        max(dnorm(hypothesized, hypothesized, SD)) * .8,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.8,
         labels = paste("p-value:", pvalue),
         pos = 2,
         col = "red"
       )
     } else if (alternative == "two.sided" || alternative == "not.equal") {
-      pvalue = signif(2 * pnorm(-1 * abs(zvalue)), 4)
+      pvalue <- signif(2 * pnorm(-1 * abs(zvalue)), 4)
       if (statistic < hypothesized) {
-        drawseq1 = seq(min, statistic, .001)
-        drawseq2 = seq(hypothesized + (hypothesized - statistic), max, .001)
+        drawseq1 <- seq(min, statistic, 0.001)
+        drawseq2 <- seq(hypothesized + (hypothesized - statistic), max, 0.001)
       } else {
-        drawseq1 = seq(min, hypothesized - (statistic - hypothesized), .001)
-        drawseq2 = seq(statistic, max, .001)
+        drawseq1 <- seq(min, hypothesized - (statistic - hypothesized), 0.001)
+        drawseq2 <- seq(statistic, max, 0.001)
       }
       polygon(
         c(min, drawseq1, drawseq1[length(drawseq1)]),
@@ -1184,42 +1183,40 @@ iscamtwopropztest <- function(
       )
       text(
         min,
-        max(dnorm(hypothesized, hypothesized, SD)) * .9,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.9,
         labels = paste("z-statistic:", signif(zvalue, 4)),
         pos = 4,
         col = "blue"
       )
       text(
         min,
-        max(dnorm(hypothesized, hypothesized, SD)) * .8,
+        max(dnorm(hypothesized, hypothesized, SD)) * 0.8,
         labels = paste("two-sided p-value:", pvalue),
         pos = 4,
         col = "red"
       )
     }
   } #end have alternative
-  lower = NULL
-  upper = NULL
+  lower <- NULL
+  upper <- NULL
   if (!is.null(conf.level)) {
+    conf.level <- .iscam_normalize_conf_levels(conf.level)
     if (length(conf.level) > 1) {
       old <- par(mar = c(4, 2, 1.5, 4), mfrow = c(length(conf.level), 1))
       on.exit(par(old), add = TRUE)
     }
-    for (k in 1:length(conf.level)) {
-      if (conf.level[k] > 1) {
-        conf.level[k] = conf.level[k] / 100
-      }
+    for (k in seq_along(conf.level)) {
       #myout=prop.test(observed, n, p=statistic, alternative="two.sided", conf.level, correct=FALSE)
-      criticalvalue = qnorm((1 - conf.level[k]) / 2)
-      sephat = sqrt(
+      criticalvalue <- qnorm((1 - conf.level[k]) / 2)
+      sephat <- sqrt(
         statistic1 *
           (1 - statistic1) /
           n1 +
           statistic2 * (1 - statistic2) / n2
       )
-      lower[k] = statistic + criticalvalue * sephat
-      upper[k] = statistic - criticalvalue * sephat
-      multconflevel = 100 * conf.level[k]
+      lower[k] <- statistic + criticalvalue * sephat
+      upper[k] <- statistic - criticalvalue * sephat
+      multconflevel <- 100 * conf.level[k]
       if (verbose) {
         cat(
           multconflevel,
@@ -1232,13 +1229,13 @@ iscamtwopropztest <- function(
       }
     }
     if (is.null(alternative)) {
-      min = statistic - 4 * sephat
-      max = statistic + 4 * sephat
-      CIseq = seq(min, max, .001)
+      min <- statistic - 4 * sephat
+      max <- statistic + 4 * sephat
+      CIseq <- seq(min, max, 0.001)
       if (length(conf.level) == 1) {
-        old <- par(mar = c(4, .5, 1.5, .5), mfrow = c(3, 1))
+        old <- par(mar = c(4, 0.5, 1.5, 0.5), mfrow = c(3, 1))
         on.exit(par(old), add = TRUE)
-        myxlab = substitute(
+        myxlab <- substitute(
           paste("Normal (", mean == x1, ", ", SD == x2, ")", ),
           list(x1 = signif(lower[1], 4), x2 = signif(sephat, 4))
         )
@@ -1247,23 +1244,24 @@ iscamtwopropztest <- function(
           "difference in sample proportions",
           side = 1,
           line = 1.75,
-          adj = .5,
-          cex = .75
+          adj = 0.5,
+          cex = 0.75
         )
-        topseq = seq(statistic, max, .001)
+        topseq <- seq(statistic, max, 0.001)
         polygon(
           c(statistic, topseq, max),
           c(0, dnorm(topseq, lower[1], sephat), 0),
           col = "red"
         )
         title(myxlab)
-        myxlab = substitute(
+        myxlab <- substitute(
           paste("Normal (", mean == x1, ", ", SD == x2, ")", ),
           list(x1 = signif(upper[1], 4), x2 = signif(sephat, 4))
         )
+        upper_curve <- seq(min, max, 0.001)
         plot(
-          seq(min, max, .001),
-          dnorm(seq(min, max, .001), upper[1], sephat),
+          upper_curve,
+          dnorm(upper_curve, upper[1], sephat),
           type = "l",
           xlab = " "
         )
@@ -1271,10 +1269,10 @@ iscamtwopropztest <- function(
           "difference in sample proportions",
           side = 1,
           line = 1.75,
-          adj = .5,
-          cex = .75
+          adj = 0.5,
+          cex = 0.75
         )
-        bottomseq = seq(min, statistic, .001)
+        bottomseq <- seq(min, statistic, 0.001)
         polygon(
           c(min, bottomseq, statistic, statistic),
           c(
@@ -1285,28 +1283,23 @@ iscamtwopropztest <- function(
           ),
           col = "red"
         )
-        newtitle = substitute(
+        newtitle <- substitute(
           paste("Normal (", mean == x1, ", ", SD == x2, ")", ),
           list(x1 = signif(upper, 4), x2 = signif(sephat, 4))
         )
         title(newtitle)
       } # end one interval
-      for (k in 1:length(conf.level)) {
-        plot(
-          c(min, statistic, max),
-          c(1, 1, 1),
-          pch = c(".", "^", "."),
-          ylab = " ",
-          xlab = "difference in process probabilities",
-          ylim = c(1, 1)
+      for (k in seq_along(conf.level)) {
+        .iscam_plot_ci_strip(
+          min_x = min,
+          statistic = statistic,
+          max_x = max,
+          lower = lower[k],
+          upper = upper[k],
+          x_label = "difference in process probabilities",
+          ci_label = paste(100 * conf.level[k], "% CI:"),
+          ci_label_x = min * 1.01
         )
-        abline(v = statistic, col = "gray")
-        text(min * 1.01, 1, labels = paste(100 * conf.level[k], "% CI:"))
-        text(statistic, .9, labels = signif(statistic, 4))
-        text(lower[k], 1, labels = signif(lower[k], 4), pos = 3)
-        text(upper[k], 1, labels = signif(upper[k], 4), pos = 3)
-        points(c(lower[k], upper[k]), c(1, 1), pch = c("[", "]"))
-        lines(c(lower[k], upper[k]), c(1, 1))
       }
     } # end have alternative
   } # end have confidence level
