@@ -17,29 +17,28 @@
 #' iscaminvt(0.95, df = 30, direction = "between")
 #' iscaminvt(0.05, df = 20, direction = "outside")
 iscaminvt <- function(prob, df, direction, verbose = TRUE) {
+  if (.iscam_maybe_help(prob, "iscaminvt")) {
+    return(invisible())
+  }
+
   old <- par(mar = c(4, 3, 2, 2))
   on.exit(par(old), add = TRUE)
 
   min <- -4
   max <- 4
   ymax <- dt(0, df)
-  thisx <- seq(min, max, .001)
-  plot(
-    thisx,
-    dt(thisx, df),
-    xlab = "",
-    ylab = "density",
-    type = "l",
-    panel.first = grid()
+  thisx <- seq(min, max, by = max(0.001, abs(max - min) / 2000))
+  .iscam_plot_continuous_distribution(
+    x = thisx,
+    density_y = dt(thisx, df),
+    x_label = "t-values",
+    y_label = "density",
+    baseline_col = "black"
   )
   title(paste("t (df =", df, ")"))
-  mtext(side = 1, line = 2, "t-values")
-  mtext(side = 2, line = 2, "density")
-
-  abline(h = 0, col = "black")
   if (direction == "below") {
     answer <- signif(qt(prob, df, lower.tail = TRUE), 4)
-    thisrange <- seq(min, answer, .001)
+    thisrange <- seq(min, answer, by = max(0.001, abs(answer - min) / 2000))
     # should we use min instead of zero?
     polygon(c(thisrange, answer, 0), c(dt(thisrange, df), 0, 0), col = "pink")
     text(
@@ -49,9 +48,10 @@ iscaminvt <- function(prob, df, direction, verbose = TRUE) {
       pos = 2,
       col = "blue"
     )
+    # jarl-ignore true_false_symbol: not using T as TRUE
     text(
       answer,
-      min(dt(answer, df), ymax * .85),
+      min(dt(answer, df), ymax * 0.85),
       labels = bquote(T <= .(answer)),
       col = "red",
       pos = 3
@@ -68,7 +68,7 @@ iscaminvt <- function(prob, df, direction, verbose = TRUE) {
     invisible(list("answer" = answer))
   } else if (direction == "above") {
     answer <- signif(qt(prob, df, lower.tail = FALSE), 4)
-    thisrange <- seq(answer, max, .001)
+    thisrange <- seq(answer, max, by = max(0.001, abs(max - answer) / 2000))
     polygon(c(answer, thisrange, max), c(0, dt(thisrange, df), 0), col = "pink")
     text(
       (answer + max) / 2,
@@ -77,9 +77,10 @@ iscaminvt <- function(prob, df, direction, verbose = TRUE) {
       pos = 4,
       col = "blue"
     )
+    # jarl-ignore true_false_symbol: not using T as TRUE
     text(
       answer,
-      min(dt(answer, df), ymax * .85),
+      min(dt(answer, df), ymax * 0.85),
       labels = bquote(T >= .(answer)),
       col = "red",
       pos = 3
@@ -96,24 +97,30 @@ iscaminvt <- function(prob, df, direction, verbose = TRUE) {
     invisible(list("answer" = answer))
   } else if (direction == "between") {
     answer1 <- signif(qt((1 - prob) / 2, df, lower.tail = TRUE), 4)
-    answer2 <- 0 + (0 - answer1)
-    thisrange <- seq(answer1, answer2, .001)
+    answer2 <- .iscam_reflect_about(0, answer1)
+    thisrange <- seq(
+      answer1,
+      answer2,
+      by = max(0.001, abs(answer2 - answer1) / 2000)
+    )
     polygon(
       c(answer1, thisrange, answer2),
       c(0, dt(thisrange, df), 0),
       col = "pink"
     )
-    text(0, (dt(.5, df) / 2), labels = prob, col = "blue")
+    text(0, (dt(0.5, df) / 2), labels = prob, col = "blue")
+    # jarl-ignore true_false_symbol: not using T as TRUE
     text(
       answer1,
-      min(dt(answer1, df), ymax * .85),
+      min(dt(answer1, df), ymax * 0.85),
       labels = bquote(T <= .(answer1)),
       col = "red",
       pos = 3
     )
+    # jarl-ignore true_false_symbol: not using T as TRUE
     text(
       answer2,
-      min(dt(answer2, df), ymax * .85),
+      min(dt(answer2, df), ymax * 0.85),
       labels = bquote(T <= .(answer2)),
       col = "red",
       pos = 3
@@ -132,9 +139,9 @@ iscaminvt <- function(prob, df, direction, verbose = TRUE) {
     invisible(list("answer1" = answer1, "answer2" = answer2))
   } else if (direction == "outside") {
     answer1 <- signif(qt(prob / 2, df, lower.tail = TRUE), 4)
-    answer2 <- 0 + (0 - answer1)
-    thisrange1 <- seq(min, answer1, .001)
-    thisrange2 <- seq(answer2, max, .001)
+    answer2 <- .iscam_reflect_about(0, answer1)
+    thisrange1 <- seq(min, answer1, by = max(0.001, abs(answer1 - min) / 2000))
+    thisrange2 <- seq(answer2, max, by = max(0.001, abs(max - answer2) / 2000))
     polygon(
       c(min, thisrange1, answer1),
       c(0, dt(thisrange1, df), 0),
@@ -159,16 +166,18 @@ iscaminvt <- function(prob, df, direction, verbose = TRUE) {
       col = "blue",
       pos = 4
     )
+    # jarl-ignore true_false_symbol: not using T as TRUE
     text(
       answer1,
-      min(dt(answer1, df), ymax * .85),
+      min(dt(answer1, df), ymax * 0.85),
       labels = bquote(T <= .(answer1)),
       col = "red",
       pos = 3
     )
+    # jarl-ignore true_false_symbol: not using T as TRUE
     text(
       answer2,
-      min(dt(answer2, df), ymax * .85),
+      min(dt(answer2, df), ymax * 0.85),
       labels = bquote(T >= .(answer2)),
       col = "red",
       pos = 3
@@ -238,10 +247,8 @@ iscamonesamplet <- function(
   conf.level = NULL,
   verbose = TRUE
 ) {
-  Description <- "iscamonesamplet(xbar, sd, n,  hypothesized=0, alternative = NULL, conf.level =0\n This function calculates a one sample t-test and/or interval from summary statistics. \n  Input the observed mean, standard deviation, and sample size \n Input  hypothesized population mean (default is zero)  \n Optional: Input the form of alternative (\"less\", \"greater\", or \"two.sided\") \n Optional: Input confidence level(s) for a two-sided confidence interval.\n   "
-
-  if (as.character(xbar) == "?") {
-    stop(Description)
+  if (.iscam_maybe_help(xbar, "iscamonesamplet")) {
+    return(invisible())
   }
 
   if (verbose) {
@@ -267,38 +274,29 @@ iscamonesamplet <- function(
     )
   }
   if (!is.null(alternative)) {
-    if (verbose) {
-      cat(paste("Null hypothesis       : mu =", hypothesized, sep = " "), "\n")
-    }
-    altname <- switch(
-      alternative,
-      less = "<",
-      greater = ">",
-      two.sided = "<>",
-      not.equal = "<>"
+    .iscam_print_hypotheses(
+      verbose = verbose,
+      null_name = "mu",
+      alt_name = "mu",
+      hypothesized = hypothesized,
+      alternative = alternative
     )
-    if (verbose) {
-      cat(
-        paste("Alternative hypothesis: mu", altname, hypothesized, sep = " "),
-        "\n"
-      )
-    }
 
     tvalue <- (statistic - hypothesized) / se
     if (verbose) {
       cat("t-statistic:", signif(tvalue, 4), "\n")
     }
-    min <- min(-4, tvalue - .001)
+    min <- min(-4, tvalue - 0.001)
     diffmin <- min(
       hypothesized - 4 * se,
-      hypothesized - abs(hypothesized - statistic) - .01
+      hypothesized - abs(hypothesized - statistic) - 0.01
     )
-    max <- max(4, tvalue + .001)
+    max <- max(4, tvalue + 0.001)
     diffmax <- max(
       hypothesized + 4 * se,
-      hypothesized + abs(hypothesized - statistic) + .01
+      hypothesized + abs(hypothesized - statistic) + 0.01
     )
-    x <- seq(min, max, .001)
+    x <- seq(min, max, by = max(0.001, abs(max - min) / 2000))
     diffx <- x * se + hypothesized
     old <- par(mar = c(4, 3, 2, 2))
     on.exit(par(old), add = TRUE)
@@ -311,30 +309,22 @@ iscamonesamplet <- function(
       ylim = c(0, dt(0, df)),
       panel.first = grid()
     )
-    tseq <- c(
-      hypothesized - 3 * se,
-      hypothesized - 2 * se,
-      hypothesized - se,
-      hypothesized,
-      hypothesized + se,
-      hypothesized + 2 * se,
-      hypothesized + 3 * se
-    )
     mtext(side = 2, line = 2, "density")
-
-    axis(
+    .iscam_standard_score_axis(
       side = 1,
-      at = tseq,
-      labels = c("t=-3", "t=-2", "t=-1", "t=0", "t=1", "t=2", "t=3"),
-      padj = 1.2,
-      tick = FALSE,
-      col.axis = "blue"
+      center = hypothesized,
+      scale = se,
+      prefix = "t"
     )
     abline(h = 0, col = "black")
     title(paste("t (df=", df, ")"))
     if (alternative == "less") {
       pvalue <- pt(tvalue, df)
-      drawseq <- seq(diffmin, statistic, .001)
+      drawseq <- seq(
+        diffmin,
+        statistic,
+        by = max(0.001, abs(statistic - diffmin) / 2000)
+      )
       polygon(
         c(drawseq, statistic, diffmin),
         c(dt((drawseq - hypothesized) / se, df), 0, 0),
@@ -342,21 +332,25 @@ iscamonesamplet <- function(
       )
       text(
         diffmin,
-        dt(0, df) * .9,
+        dt(0, df) * 0.9,
         labels = paste("t-statistic:", signif(tvalue, 3)),
         pos = 4,
         col = "blue"
       )
       text(
         diffmin,
-        dt(0, df) * .8,
+        dt(0, df) * 0.8,
         labels = paste("p-value:", signif(pvalue, 4)),
         pos = 4,
         col = "red"
       )
     } else if (alternative == "greater") {
       pvalue <- 1 - pt(tvalue, df)
-      drawseq <- seq(statistic, diffmax, .001)
+      drawseq <- seq(
+        statistic,
+        diffmax,
+        by = max(0.001, abs(diffmax - statistic) / 2000)
+      )
       polygon(
         c(statistic, drawseq, diffmax),
         c(0, dt((drawseq - hypothesized) / se, df), 0),
@@ -364,30 +358,28 @@ iscamonesamplet <- function(
       )
       text(
         diffmax,
-        dt(0, df) * .9,
+        dt(0, df) * 0.9,
         labels = paste("t-statistic:", signif(tvalue, 3)),
         pos = 2,
         col = "blue"
       )
       text(
         diffmax,
-        dt(0, df) * .8,
+        dt(0, df) * 0.8,
         labels = paste("p-value:", signif(pvalue, 4)),
         pos = 2,
         col = "red"
       )
-    } else if (alternative == "two.sided" || alternative == "not.equal") {
+    } else if (.iscam_is_two_sided_alt(alternative)) {
       pvalue <- 2 * pt(-1 * abs(tvalue), df)
-      drawseq1 <- seq(
-        diffmin,
-        hypothesized - abs(hypothesized - statistic),
-        .001
-      )
-      drawseq2 <- seq(
-        hypothesized + abs(hypothesized - statistic),
-        diffmax,
-        .001
+      drawseq <- .iscam_two_sided_draw_sequences(
+        min_x = diffmin,
+        max_x = diffmax,
+        center = hypothesized,
+        statistic = statistic
       )
+      drawseq1 <- drawseq$left
+      drawseq2 <- drawseq$right
       polygon(
         c(diffmin, drawseq1, drawseq1[length(drawseq1)]),
         c(0, dt((drawseq1 - hypothesized) / se, df), 0),
@@ -400,14 +392,14 @@ iscamonesamplet <- function(
       )
       text(
         diffmin,
-        dt(0, df) * .9,
+        dt(0, df) * 0.9,
         labels = paste("t-statistic:", signif(tvalue, 4)),
         pos = 4,
         col = "blue"
       )
       text(
         diffmin,
-        dt(0, df) * .8,
+        dt(0, df) * 0.8,
         labels = paste("two-sided p-value:", signif(pvalue, 4)),
         pos = 4,
         col = "red"
@@ -418,16 +410,14 @@ iscamonesamplet <- function(
   lower <- NULL
   upper <- NULL
   if (!is.null(conf.level)) {
-    old <- par(mar = c(4, .5, 1.5, .5), mfrow = c(3, 1))
+    conf.level <- .iscam_normalize_conf_levels(conf.level)
+    old <- par(mar = c(4, 0.5, 1.5, 0.5), mfrow = c(3, 1))
     on.exit(par(old), add = TRUE)
     if (length(conf.level) > 1) {
-      old <- par(mar = c(4, 2, 1.5, .4), mfrow = c(length(conf.level), 1))
+      old <- par(mar = c(4, 2, 1.5, 0.4), mfrow = c(length(conf.level), 1))
       on.exit(par(old), add = TRUE)
     }
-    for (k in 1:length(conf.level)) {
-      if (conf.level[k] > 1) {
-        conf.level[k] <- conf.level[k] / 100
-      }
+    for (k in seq_along(conf.level)) {
       criticalvalue <- qt((1 - conf.level[k]) / 2, df)
       lower[k] <- statistic + criticalvalue * se
       upper[k] <- statistic - criticalvalue * se
@@ -446,14 +436,18 @@ iscamonesamplet <- function(
     if (is.null(alternative)) {
       min <- statistic - 4 * se
       max <- statistic + 4 * se
-      CIseq <- seq(min, max, .001)
+      CIseq <- seq(min, max, by = max(0.001, abs(max - min) / 2000))
       if (length(conf.level) == 1) {
-        old <- par(mar = c(4, .5, 1.5, .5), mfrow = c(3, 1))
+        old <- par(mar = c(4, 0.5, 1.5, 0.5), mfrow = c(3, 1))
         on.exit(par(old), add = TRUE)
         myxlab <- substitute(paste(mean == x1), list(x1 = signif(lower[1], 4)))
         plot(CIseq, dnorm(CIseq, lower[1], se), type = "l", xlab = " ")
-        mtext("sample means", side = 1, line = 1.75, adj = .5, cex = .75)
-        topseq <- seq(statistic, max, .001)
+        mtext("sample means", side = 1, line = 1.75, adj = 0.5, cex = 0.75)
+        topseq <- seq(
+          statistic,
+          max,
+          by = max(0.001, abs(max - statistic) / 2000)
+        )
         polygon(
           c(statistic, topseq, max),
           c(0, dnorm(topseq, lower[1], se), 0),
@@ -464,14 +458,19 @@ iscamonesamplet <- function(
           list(x1 = signif(lower[1], 4))
         )
         title(myxlab)
+        upper_curve <- seq(min, max, by = max(0.001, abs(max - min) / 2000))
         plot(
-          seq(min, max, .001),
-          dnorm(seq(min, max, .001), upper[1], se),
+          upper_curve,
+          dnorm(upper_curve, upper[1], se),
           type = "l",
           xlab = " "
         )
-        mtext("sample means", side = 1, line = 1.75, adj = .5, cex = .75)
-        bottomseq <- seq(min, statistic, .001)
+        mtext("sample means", side = 1, line = 1.75, adj = 0.5, cex = 0.75)
+        bottomseq <- seq(
+          min,
+          statistic,
+          by = max(0.001, abs(statistic - min) / 2000)
+        )
         polygon(
           c(min, bottomseq, statistic, statistic),
           c(
@@ -487,22 +486,17 @@ iscamonesamplet <- function(
           list(x1 = signif(upper[1], 4))
         ))
       } # just one interval
-      for (k in 1:length(conf.level)) {
-        plot(
-          c(min, statistic, max),
-          c(1, 1, 1),
-          pch = c(".", "^", "."),
-          ylab = " ",
-          xlab = "population mean",
-          ylim = c(1, 1)
+      for (k in seq_along(conf.level)) {
+        .iscam_plot_ci_strip(
+          min_x = min,
+          statistic = statistic,
+          max_x = max,
+          lower = lower[k],
+          upper = upper[k],
+          x_label = "population mean",
+          ci_label = paste(100 * conf.level[k], "% CI:"),
+          ci_label_x = min * 1.01
         )
-        abline(v = statistic, col = "gray")
-        text(min * 1.01, 1, labels = paste(100 * conf.level[k], "% CI:"))
-        text(statistic, .9, labels = signif(statistic, 4))
-        text(lower[k], 1, labels = signif(lower[k], 4), pos = 3)
-        text(upper[k], 1, labels = signif(upper[k], 4), pos = 3)
-        points(c(lower[k], upper[k]), c(1, 1), pch = c("[", "]"))
-        lines(c(lower[k], upper[k]), c(1, 1))
       }
     }
   }
@@ -511,15 +505,6 @@ iscamonesamplet <- function(
       cat("p-value:", pvalue, "\n")
     }
   }
-  old <- par(mfrow = c(1, 1))
-  on.exit(par(old), add = TRUE)
-  invisible(list(
-    "tvalue" = tvalue,
-    "pvalue" = pvalue,
-    "lower" = lower,
-    "upper" = upper
-  ))
-
   old <- par(mfrow = c(1, 1))
   on.exit(par(old), add = TRUE)
   invisible()
@@ -596,6 +581,10 @@ iscamtwosamplet <- function(
   conf.level = 0,
   verbose = TRUE
 ) {
+  if (.iscam_maybe_help(x1, "iscamtwosamplet")) {
+    return(invisible())
+  }
+
   old <- par(mar = c(4, 3, 2, 2))
   on.exit(par(old), add = TRUE)
   if (verbose) {
@@ -641,51 +630,34 @@ iscamtwosamplet <- function(
   }
 
   if (!is.null(alternative)) {
-    if (verbose) {
-      cat(
-        paste("Null hypothesis       : mu1-mu2 =", hypothesized, sep = " "),
-        "\n"
-      )
-    }
-    altname <- switch(
-      alternative,
-      less = "<",
-      greater = ">",
-      two.sided = "<>",
-      not.equal = "<>"
+    .iscam_print_hypotheses(
+      verbose = verbose,
+      null_name = "mu1-mu2",
+      alt_name = "mu1-mu2",
+      hypothesized = hypothesized,
+      alternative = alternative
     )
-    if (verbose) {
-      cat(
-        paste(
-          "Alternative hypothesis: mu1-mu2",
-          altname,
-          hypothesized,
-          sep = " "
-        ),
-        "\n"
-      )
-    }
 
     tvalue <- (statistic1 - statistic2 - hypothesized) / unpooledsd
     if (verbose) {
       cat("t-statistic:", signif(tvalue, 4), "\n")
       cat("df:", signif(df, 4), "\n")
     }
-    min <- min(-4, tvalue - .001)
+    min <- min(-4, tvalue - 0.001)
     diffmin <- min(
       hypothesized - 4 * unpooledsd,
       min(
         hypothesized - 4 * unpooledsd,
-        hypothesized - abs(hypothesized - statistic) - .001
+        hypothesized - abs(hypothesized - statistic) - 0.001
       )
     )
-    max <- max(4, tvalue + .001)
+    max <- max(4, tvalue + 0.001)
     diffmax <- max(
       hypothesized + 4 * unpooledsd,
-      hypothesized + abs(hypothesized - statistic) + .001
+      hypothesized + abs(hypothesized - statistic) + 0.001
     )
 
-    x <- seq(min, max, .001)
+    x <- seq(min, max, by = max(0.001, abs(max - min) / 2000))
     diffx <- x * unpooledsd + hypothesized
     plot(
       diffx,
@@ -696,23 +668,11 @@ iscamtwosamplet <- function(
       ylim = c(0, dt(0, df)),
       panel.first = grid()
     )
-    tseq <- c(
-      hypothesized - 3 * unpooledsd,
-      hypothesized - 2 * unpooledsd,
-      hypothesized - unpooledsd,
-      hypothesized,
-      hypothesized + unpooledsd,
-      hypothesized + 2 * unpooledsd,
-      hypothesized + 3 * unpooledsd
-    )
-
-    axis(
+    .iscam_standard_score_axis(
       side = 1,
-      at = tseq,
-      labels = c("t=-3", "t=-2", "t=-1", "t=0", "t=1", "t=2", "t=3"),
-      padj = 1.2,
-      tick = FALSE,
-      col.axis = "blue"
+      center = hypothesized,
+      scale = unpooledsd,
+      prefix = "t"
     )
     abline(h = 0, col = "black")
     mtext(side = 2, line = 2, "density")
@@ -721,7 +681,11 @@ iscamtwosamplet <- function(
     if (alternative == "less") {
       pvalue <- signif(pt(tvalue, df), 4)
       tvalue <- signif(tvalue, 4)
-      drawseq <- seq(diffmin, statistic, .001)
+      drawseq <- seq(
+        diffmin,
+        statistic,
+        by = max(0.001, abs(statistic - diffmin) / 2000)
+      )
       polygon(
         c(drawseq, statistic, diffmin),
         c(dt((drawseq - hypothesized) / unpooledsd, df), 0, 0),
@@ -729,14 +693,14 @@ iscamtwosamplet <- function(
       )
       text(
         diffmin,
-        dt(0, df) * .9,
+        dt(0, df) * 0.9,
         labels = paste("t-statistic:", tvalue),
         pos = 4,
         col = "blue"
       )
       text(
         diffmin,
-        dt(0, df) * .8,
+        dt(0, df) * 0.8,
         labels = paste("p-value:", pvalue),
         pos = 4,
         col = "red"
@@ -744,7 +708,11 @@ iscamtwosamplet <- function(
     } else if (alternative == "greater") {
       pvalue <- signif(1 - pt(tvalue, df), 4)
       tvalue <- signif(tvalue, 3)
-      drawseq <- seq(statistic, diffmax, .001)
+      drawseq <- seq(
+        statistic,
+        diffmax,
+        by = max(0.001, abs(diffmax - statistic) / 2000)
+      )
       polygon(
         c(statistic, drawseq, diffmax),
         c(0, dt((drawseq - hypothesized) / unpooledsd, df), 0),
@@ -752,31 +720,29 @@ iscamtwosamplet <- function(
       )
       text(
         diffmax,
-        dt(0, df) * .9,
+        dt(0, df) * 0.9,
         labels = paste("t-statistic:", tvalue),
         pos = 2,
         col = "blue"
       )
       text(
         diffmax,
-        dt(0, df) * .8,
+        dt(0, df) * 0.8,
         labels = paste("p-value:", pvalue),
         pos = 2,
         col = "red"
       )
-    } else if (alternative == "two.sided" || alternative == "not.equal") {
+    } else if (.iscam_is_two_sided_alt(alternative)) {
       pvalue <- signif(2 * pt(-1 * abs(tvalue), df), 4)
       tvalue <- signif(tvalue, 4)
-      drawseq1 <- seq(
-        diffmin,
-        hypothesized - abs(hypothesized - statistic),
-        .001
-      )
-      drawseq2 <- seq(
-        hypothesized + abs(hypothesized - statistic),
-        diffmax,
-        .001
+      drawseq <- .iscam_two_sided_draw_sequences(
+        min_x = diffmin,
+        max_x = diffmax,
+        center = hypothesized,
+        statistic = statistic
       )
+      drawseq1 <- drawseq$left
+      drawseq2 <- drawseq$right
       polygon(
         c(diffmin, drawseq1, drawseq1[length(drawseq1)]),
         c(0, dt((drawseq1 - hypothesized) / unpooledsd, df), 0),
@@ -789,14 +755,14 @@ iscamtwosamplet <- function(
       )
       text(
         diffmin,
-        dt(0, df) * .9,
+        dt(0, df) * 0.9,
         labels = paste("t-statistic:", tvalue),
         pos = 4,
         col = "blue"
       )
       text(
         diffmin,
-        dt(0, df) * .8,
+        dt(0, df) * 0.8,
         labels = paste("two-sided p-value:", pvalue),
         pos = 4,
         col = "red"
@@ -807,9 +773,7 @@ iscamtwosamplet <- function(
   upper <- NULL
 
   if (conf.level != 0) {
-    if (conf.level > 1) {
-      conf.level <- conf.level / 100
-    }
+    conf.level <- .iscam_normalize_conf_levels(conf.level)
     criticalvalue <- qt((1 - conf.level) / 2, df)
     lower <- statistic + criticalvalue * unpooledsd
     upper <- statistic - criticalvalue * unpooledsd
@@ -827,8 +791,8 @@ iscamtwosamplet <- function(
     if (is.null(alternative)) {
       min <- statistic - 4 * unpooledsd
       max <- statistic + 4 * unpooledsd
-      CIseq <- seq(min, max, .001)
-      old <- par(mar = c(4, .5, 1.5, .5), mfrow = c(3, 1))
+      CIseq <- seq(min, max, by = max(0.001, abs(max - min) / 2000))
+      old <- par(mar = c(4, 0.5, 1.5, 0.5), mfrow = c(3, 1))
       on.exit(par(old), add = TRUE)
       myxlab <- substitute(paste(mean == x1), list(x1 = signif(lower, 4)))
       plot(CIseq, dnorm(CIseq, lower, unpooledsd), type = "l", xlab = " ")
@@ -836,10 +800,14 @@ iscamtwosamplet <- function(
         "difference in sample means",
         side = 1,
         line = 1.75,
-        adj = .5,
-        cex = .75
+        adj = 0.5,
+        cex = 0.75
+      )
+      topseq <- seq(
+        statistic,
+        max,
+        by = max(0.001, abs(max - statistic) / 2000)
       )
-      topseq <- seq(statistic, max, .001)
       polygon(
         c(statistic, topseq, max),
         c(0, dnorm(topseq, lower, unpooledsd), 0),
@@ -850,9 +818,10 @@ iscamtwosamplet <- function(
         list(x1 = signif(lower, 4))
       )
       title(myxlab)
+      upper_curve <- seq(min, max, by = max(0.001, abs(max - min) / 2000))
       plot(
-        seq(min, max, .001),
-        dnorm(seq(min, max, .001), upper, unpooledsd),
+        upper_curve,
+        dnorm(upper_curve, upper, unpooledsd),
         type = "l",
         xlab = " "
       )
@@ -860,10 +829,14 @@ iscamtwosamplet <- function(
         "difference in sample means",
         side = 1,
         line = 1.75,
-        adj = .5,
-        cex = .75
+        adj = 0.5,
+        cex = 0.75
+      )
+      bottomseq <- seq(
+        min,
+        statistic,
+        by = max(0.001, abs(statistic - min) / 2000)
       )
-      bottomseq <- seq(min, statistic, .001)
       polygon(
         c(min, bottomseq, statistic, statistic),
         c(
@@ -879,21 +852,16 @@ iscamtwosamplet <- function(
         list(x1 = signif(upper, 4))
       ))
 
-      plot(
-        c(min, statistic, max),
-        c(1, 1, 1),
-        pch = c(".", "^", "."),
-        ylab = " ",
-        xlab = "difference in process means",
-        ylim = c(1, 1)
+      .iscam_plot_ci_strip(
+        min_x = min,
+        statistic = statistic,
+        max_x = max,
+        lower = lower,
+        upper = upper,
+        x_label = "difference in process means",
+        ci_label = paste(multconflevel, "% CI:"),
+        ci_label_x = min * 1.01
       )
-      abline(v = statistic, col = "gray")
-      text(min * 1.01, 1, labels = paste(multconflevel, "% CI:"))
-      text(statistic, .9, labels = signif(statistic, 4))
-      text(lower, 1, labels = signif(lower, 4), pos = 3)
-      text(upper, 1, labels = signif(upper, 4), pos = 3)
-      points(c(lower, upper), c(1, 1), pch = c("[", "]"))
-      lines(c(lower, upper), c(1, 1))
     }
   }
   if (!is.null(alternative)) {
@@ -923,7 +891,7 @@ iscamtwosamplet <- function(
 #' @param verbose Logical; if `TRUE`, print textual descriptions of results.
 #'
 #' @return The tail probability in the specified direction using the given
-#' parameters.
+#' arguments.
 #' @export
 #' @param verbose Logical, defaults to `TRUE`. Set to `FALSE` to suppress messages
 #' @examples
@@ -932,33 +900,30 @@ iscamtwosamplet <- function(
 #' iscamtprob(xval = -2, xval2 = 2, df = 15, direction = "between")
 #' iscamtprob(xval = -2.5, xval2 = 2.5, df = 25, direction = "outside")
 iscamtprob <- function(xval, df, direction, xval2 = NULL, verbose = TRUE) {
+  if (.iscam_maybe_help(xval, "iscamtprob")) {
+    return(invisible())
+  }
+
   old <- par(mar = c(4, 4, 2, 1))
   on.exit(par(old), add = TRUE)
-  minx <- min(-5, -1 * abs(xval) - .5)
-  maxx <- max(5, abs(xval) + .5)
-  thisx <- seq(minx, maxx, .001)
-  plot(
-    thisx,
-    dt(thisx, df),
+  minx <- min(-5, -1 * abs(xval) - 0.5)
+  maxx <- max(5, abs(xval) + 0.5)
+  thisx <- seq(minx, maxx, by = max(0.001, abs(maxx - minx) / 2000))
+  .iscam_plot_continuous_distribution(
+    x = thisx,
+    density_y = dt(thisx, df),
     xlim = c(minx, maxx),
-    type = "l",
-    xlab = "",
-    ylab = "",
-    panel.first = grid()
+    x_label = "t-values",
+    y_label = "density"
   )
-  abline(h = 0, col = "gray")
-  mtext(side = 1, line = 2, "t-values")
-  mtext(side = 2, line = 2, "density")
 
   if (direction == "below") {
-    probseq <- seq(minx, max(minx, xval), .001)
     tprob <- pt(xval, df)
     showprob <- format(tprob, digits = 4)
-    polygon(
-      c(probseq, max(minx, xval), minx),
-      c(dt(probseq, df), 0, 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_left_tail(
+      min_x = minx,
+      x_end = max(minx, xval),
+      density_fn = function(v) dt(v, df)
     )
     text(
       minx,
@@ -968,19 +933,13 @@ iscamtprob <- function(xval, df, direction, xval2 = NULL, verbose = TRUE) {
       pos = 4
     )
   } else if (direction == "above") {
-    probseq <- seq(min(xval, maxx), maxx, .001)
     tprob <- pt(xval, df, lower.tail = FALSE)
     showprob <- format(tprob, digits = 4)
-    polygon(
-      c(min(maxx, xval), probseq, maxx),
-      c(0, dt(probseq, df), 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_right_tail(
+      x_start = min(maxx, xval),
+      max_x = maxx,
+      density_fn = function(v) dt(v, df)
     )
-    if (verbose) {
-      print(xval)
-      print(maxx)
-    }
     text(
       maxx,
       dt(0, df) / 2,
@@ -989,22 +948,19 @@ iscamtprob <- function(xval, df, direction, xval2 = NULL, verbose = TRUE) {
       pos = 2
     )
   } else if (direction == "between") {
-    if (is.null(xval2)) {
-      stop("You need to specify a second observation value.")
-    }
-    if (xval2 < xval) {
-      temp <- xval
-      xval <- xval2
-      xval2 <- temp
-    }
-    probseq <- seq(xval, xval2, .001)
+    ordered_vals <- .iscam_resolve_interval_bounds(
+      xval = xval,
+      xval2 = xval2,
+      direction = direction
+    )
+    xval <- ordered_vals[1]
+    xval2 <- ordered_vals[2]
     tprob <- pt(xval2, df) - pt(xval, df)
     showprob <- format(tprob, digits = 4)
-    polygon(
-      c(xval, probseq, xval2),
-      c(0, dt(probseq, df), 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_between(
+      x_start = xval,
+      x_end = xval2,
+      density_fn = function(v) dt(v, df)
     )
     text(
       minx,
@@ -1018,30 +974,26 @@ iscamtprob <- function(xval, df, direction, xval2 = NULL, verbose = TRUE) {
       pos = 4
     )
   } else if (direction == "outside") {
+    ordered_vals <- .iscam_resolve_interval_bounds(
+      xval = xval,
+      xval2 = xval2,
+      direction = direction
+    )
+    xval <- ordered_vals[1]
+    xval2 <- ordered_vals[2]
     maxx <- max(maxx, xval2)
-    if (is.null(xval2)) {
-      stop("You need to specify a second observation value.")
-    }
-    if (xval2 < xval) {
-      temp <- xval
-      xval <- xval2
-      xval2 <- temp
-    }
-    probseq1 <- seq(minx, xval, .001)
-    probseq2 <- seq(xval2, maxx, .001)
     tprob <- 1 - (pt(xval2, df) - pt(xval, df))
     showprob <- format(tprob, digits = 4)
-    polygon(
-      c(minx, probseq1, xval),
-      c(0, dt(probseq1, df), 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_left_tail(
+      min_x = minx,
+      x_end = xval,
+      density_fn = function(v) dt(v, df),
+      baseline_start = TRUE
     )
-    polygon(
-      c(xval2, probseq2, maxx),
-      c(0, dt(probseq2, df), 0),
-      col = "red",
-      border = "red"
+    .iscam_shade_right_tail(
+      x_start = xval2,
+      max_x = maxx,
+      density_fn = function(v) dt(v, df)
     )
     text(
       -2,
@@ -1052,13 +1004,10 @@ iscamtprob <- function(xval, df, direction, xval2 = NULL, verbose = TRUE) {
       ))
     )
   } else {
-    stop(
-      "Use \"above\", \"below\", \"between\", or \"outside\" as the direction."
-    )
+    .iscam_stop_invalid_direction()
   }
 
   title(substitute(paste("t(", df == x3, ")"), list(x3 = df)))
-  if (verbose) {
-    cat(c("probability:", showprob), "\n")
-  }
+  .iscam_print_probability(verbose, showprob)
+  invisible(showprob)
 }
