@@ -49,3 +49,8 @@ test_that("summary with explanatory works", {
       structure(row.names = c("group1", "group2", "group3"))
   )
 })
+
+test_that("iscamsummary prints help for question mark", {
+  help_lines <- capture_help_output(ISCAM::iscamsummary("?"))
+  expect_snapshot(collapse_output(help_lines))
+})
